@@ -20,6 +20,7 @@
 #include <QDebug>
 #include <QStyleOptionGraphicsItem>
 #include <QPainter>
+#include <QFont>
 #include "StelGuiItems.hpp"
 #include "StelApp.hpp"
 #include "StelCore.hpp"
@@ -28,7 +29,7 @@
 #include "StelModuleMgr.hpp"
 #include "StelTranslator.hpp"
 #include "StelScriptMgr.hpp"
-
+#include "StelFileMgr.hpp"
 #include "Calendars.hpp"
 #include "CalendarsDialog.hpp"
 
@@ -142,13 +143,25 @@ Calendars::Calendars():
 	flagShowTibetan(false)
 {
 	setObjectName("Calendars");
-	font.setPixelSize(StelApp::getInstance().getScreenFontSize());
+	int fontSize = StelApp::getInstance().getScreenFontSize();
 
 	configDialog = new CalendarsDialog();
 	conf = StelApp::getInstance().getSettings();
 
 	infoPanel=new CalendarsInfoPanel(this, static_cast<StelGui*>(StelApp::getInstance().getGui())->getSkyGui());
-	connect(&StelApp::getInstance(), &StelApp::screenFontSizeChanged, this, [=](int size){font.setPixelSize(size); infoPanel->setFont(font); infoPanel->updatePosition(true);});
+	QFont pFont=QGuiApplication::font();
+	pFont.setPixelSize(fontSize);
+	infoPanel->setFont(pFont);
+	connect(&StelApp::getInstance(), &StelApp::fontChanged, this, [=](const QFont &font){
+		QFont pFont=font;
+		pFont.setPixelSize(fontSize);
+		infoPanel->setFont(pFont);
+		infoPanel->updatePosition(true);});
+	connect(&StelApp::getInstance(), &StelApp::screenFontSizeChanged, this, [=](int size){
+		QFont f=infoPanel->font();
+		f.setPixelSize(size);
+		infoPanel->setFont(f);
+		infoPanel->updatePosition(true);});
 }
 
 /*************************************************************************
@@ -157,9 +170,9 @@ Calendars::Calendars():
 Calendars::~Calendars()
 {
 	delete configDialog; configDialog=nullptr;
-	foreach (QString key, calendars.keys())
+	for (auto c = calendars.cbegin(), end = calendars.cend(); c != end; ++c)
 	{
-		Calendar *cal = calendars.take(key);
+		Calendar *cal = calendars.take(c.key());
 		delete cal;
 	}
 	if (infoPanel) delete infoPanel;
@@ -192,6 +205,8 @@ void Calendars::init()
 	QString section=N_("Calendars");
 	addAction("actionShow_Calendars",         section, N_("Calendars"), "enabled", "Alt+K");
 	addAction("actionShow_Calendars_dialog",  section, N_("Show settings dialog"),  configDialog,  "visible",           "Alt+Shift+K");
+	// No hotkey here, but users can define their own
+	addAction("actionShow_Calendars_export",  section, N_("Export to Calendars.html"),  this,  "exportCalendars()");
 
 	// Add a toolbar button
 	StelApp& app=StelApp::getInstance();
@@ -214,10 +229,9 @@ void Calendars::init()
 	}
 	catch (std::runtime_error& e)
 	{
-		qWarning() << "WARNING: unable to create toolbar button for Calendars plugin: " << e.what();
+		qWarning() << "Unable to create toolbar button for Calendars plugin: " << e.what();
 	}
 
-	infoPanel->setFont(font);
 	infoPanel->setPos(600, 300);
 
 	const double jd=StelApp::getInstance().getCore()->getJD();
@@ -349,12 +363,40 @@ void Calendars::draw(StelCore* core)
 		infoPanel->hide();
 		return;
 	}
+	if (calendars.count()==0) return;
 
+	QString str = createTableToDraw();
+	Vec3f color(1);
+	if (getFlagTextColorOverride())
+	{
+		color=textColor;
+	}
+	else
+	{
+		if (StelApp::getInstance().getFlagOverwriteInfoColor())
+		{
+			// make info text more readable...
+			color = StelApp::getInstance().getOverwriteInfoColor();
+		}
+		if (core->isBrightDaylight() && !StelApp::getInstance().getVisionModeNight())
+		{
+			// make info text more readable when atmosphere enabled at daylight.
+			color = StelApp::getInstance().getDaylightInfoColor();
+		}
+	}
+
+	infoPanel->setDefaultTextColor(color.toQColor());
+	infoPanel->setHtml(str);
+	infoPanel->updatePosition();
+	infoPanel->show();
+}
+
+QString Calendars::createTableToDraw()
+{
 	QString str;
 	QTextStream oss(&str);
 	oss << "<table>";
 	// Select the drawable calendars from GUI or settings.
-	if (calendars.count()==0) return;
 	if (flagShowGregorian)          oss << QString("<tr><td>%1&nbsp;</td><td>%2</td></tr>").arg(qc_("Gregorian",             "calendar"), getCal("Gregorian")->getFormattedDateString());
 	if (flagShowJulian)             oss << QString("<tr><td>%1&nbsp;</td><td>%2</td></tr>").arg(qc_("Julian",                "calendar"), getCal("Julian")->getFormattedDateString());
 	if (flagShowRevisedJulian)      oss << QString("<tr><td>%1&nbsp;</td><td>%2</td></tr>").arg(qc_("Revised Julian",        "calendar"), getCal("RevisedJulian")->getFormattedDateString());
@@ -407,29 +449,22 @@ void Calendars::draw(StelCore* core)
 	if (flagShowAztecXihuitl)       oss << QString("<tr><td>%1&nbsp;</td><td>%2</td></tr>").arg(qc_("Aztec Xihuitl",         "calendar"), getCal("AztecXihuitl")->getFormattedDateString());
 	if (flagShowAztecTonalpohualli) oss << QString("<tr><td>%1&nbsp;</td><td>%2</td></tr>").arg(qc_("Aztec Tonalpohualli",   "calendar"), getCal("AztecTonalpohualli")->getFormattedDateString());
 	oss << "</table>";
-	Vec3f color(1);
-	if (getFlagTextColorOverride())
-	{
-		color=textColor;
-	}
-	else
-	{
-		if (StelApp::getInstance().getFlagOverwriteInfoColor())
-		{
-			// make info text more readable...
-			color = StelApp::getInstance().getOverwriteInfoColor();
-		}
-		if (core->isBrightDaylight() && !StelApp::getInstance().getVisionModeNight())
-		{
-			// make info text more readable when atmosphere enabled at daylight.
-			color = StelApp::getInstance().getDaylightInfoColor();
-		}
-	}
+	return str;
+}
 
-	infoPanel->setDefaultTextColor(color.toQColor());
-	infoPanel->setHtml(str);
-	infoPanel->updatePosition();
-	infoPanel->show();
+void Calendars::exportCalendars()
+{
+	QString html=createTableToDraw();
+	QString fileName=StelFileMgr::getUserDir() + "/Calendar.html";
+	QFile file(fileName);
+	if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate | QIODevice::Text | QIODevice::Unbuffered))
+	{
+		qWarning() << "ERROR: Cannot open file" << fileName;
+		return;
+	}
+	QTextStream out(&file);
+	out << (html);
+	file.close();
 }
 
 // Get a pointer to the respective calendar
