@@ -19,7 +19,6 @@
 #ifndef CALENDARS_HPP
 #define CALENDARS_HPP
 
-#include <QFont>
 #include <QMap>
 
 #include "StelModule.hpp"
@@ -70,7 +69,7 @@ See Qt documentation on QtTimeZone.
 */
 
 //! @class Calendars
-//! StelModule plugin which provides display and a scripting interface to a multitude of calendrical functions.
+//! @brief StelModule plugin which provides display and a scripting interface to a multitude of calendrical functions.
 //! @author Georg Zotti
 //! @ingroup calendars
 
@@ -214,6 +213,8 @@ public slots:
 	//! Get the current color of the text (when override flag is active).
 	Vec3f getTextColor() const;
 	void setTextColor(const Vec3f& newColor);
+	//! Simple hotkey action to export the currently shown calendar data to $USER_DATA_DIR/Calendars.html
+	void exportCalendars();
 
 	//! enable display of calendars overlay
 	void enable(bool b);
@@ -293,8 +294,8 @@ public slots:
 	void showTibetan(bool b);	        //!< activate display of Tibetan
 
 private:
-	// Font used for displaying text
-	QFont font;
+	//! Create an HTML table which can be displayed or exported
+	QString createTableToDraw();
 	CalendarsInfoPanel *infoPanel;
 	CalendarsDialog* configDialog;
 	StelButton* toolbarButton;
