@@ -273,6 +273,7 @@ void LensDistortionEstimatorDialog::createDialogContent()
 	connectBoolProperty(ui_->imageAxesEnabled, "LensDistortionEstimator.imageAxesEnabled");
 	connectBoolProperty(ui_->markPickedPoints, "LensDistortionEstimator.pointMarkersEnabled");
 	connectBoolProperty(ui_->markProjectionCenter, "LensDistortionEstimator.projectionCenterMarkerEnabled");
+	connectBoolProperty(ui_->imgPosResetOnLoadingEnabled, "LensDistortionEstimator.imgPosResetOnLoadingEnabled");
 	ui_->imageAxesColor->setup("LensDistortionEstimator.imageAxesColor", "LensDistortionEstimator/image_axes_color");
 	ui_->pointMarkerColor->setup("LensDistortionEstimator.pointMarkerColor", "LensDistortionEstimator/point_marker_color");
 	ui_->selectedPointMarkerColor->setup("LensDistortionEstimator.selectedPointMarkerColor",
@@ -1246,7 +1247,8 @@ void LensDistortionEstimatorDialog::updateImage()
 	imageChanged_ = true;
 	setupGenerateLensfunModelButton();
 	computeColorToSubtract();
-	placeImageInCenterOfScreen();
+	if(ui_->imgPosResetOnLoadingEnabled->isChecked())
+		placeImageInCenterOfScreen();
 
 #ifdef HAVE_EXIV2
 	try
@@ -1744,7 +1746,7 @@ void LensDistortionEstimatorDialog::setAboutText()
 {
 	QString html = "<html><head></head><body>"
 	"<h2>" + q_("Lens Distortion Estimator Plug-in") + "</h2>"
-	"<table width=\"90%\">"
+	"<table class='layout' width=\"90%\">"
 		"<tr width=\"30%\"><td><strong>" + q_("Version") + ":</strong></td><td>" + LENSDISTORTIONESTIMATOR_PLUGIN_VERSION + "</td></tr>"
 		"<tr><td><strong>" + q_("License") + ":</strong></td><td>" + LENSDISTORTIONESTIMATOR_PLUGIN_LICENSE + "</td></tr>"
 		"<tr><td><strong>" + q_("Author") + ":</strong></td><td>Ruslan Kabatsayev &lt;b7.10110111+stellarium@gmail.com&gt;</td></tr>"
