@@ -37,14 +37,14 @@ class PulsarsDialog : public StelDialog
 
 public:
 	PulsarsDialog();
-	~PulsarsDialog() Q_DECL_OVERRIDE;
+	~PulsarsDialog() override;
 
 protected:
 	//! Initialize the dialog widgets and connect the signals/slots
-	void createDialogContent() Q_DECL_OVERRIDE;
+	void createDialogContent() override;
 
 public slots:
-	void retranslate() Q_DECL_OVERRIDE;
+	void retranslate() override;
 	void refreshUpdateValues(void);
 
 private slots:
