@@ -20,23 +20,22 @@
 #define SIMPLEDRAWLINE_HPP
 
 #include "StelModule.hpp"
-#include <QFont>
 
 //! This is an example of a plug-in which can be dynamically loaded into stellarium
 class SimpleDrawLine : public StelModule
 {
 public:
 	SimpleDrawLine();
-	virtual ~SimpleDrawLine() Q_DECL_OVERRIDE;
+	~SimpleDrawLine() override;
 
 	///////////////////////////////////////////////////////////////////////////
 	// Methods defined in the StelModule class
-	virtual void init() Q_DECL_OVERRIDE;
-	virtual void draw(StelCore* core) Q_DECL_OVERRIDE;
-	virtual double getCallOrder(StelModuleActionName actionName) const Q_DECL_OVERRIDE;
+	void init() override;
+	void draw(StelCore* core) override;
+	double getCallOrder(StelModuleActionName actionName) const override;
 private:
-	// Font used for displaying our text
-	QFont font;
+	// Font size used for displaying our text
+	int fontSize;
 };
 
 
@@ -50,9 +49,9 @@ class SimpleDrawLineStelPluginInterface : public QObject, public StelPluginInter
 	Q_PLUGIN_METADATA(IID StelPluginInterface_iid)
 	Q_INTERFACES(StelPluginInterface)
 public:
-	virtual StelModule* getStelModule() const Q_DECL_OVERRIDE;
-	virtual StelPluginInfo getPluginInfo() const Q_DECL_OVERRIDE;
-	//virtual QObjectList getExtensionList() const Q_DECL_OVERRIDE { return QObjectList(); }
+	StelModule* getStelModule() const override;
+	StelPluginInfo getPluginInfo() const override;
+	//QObjectList getExtensionList() const override { return QObjectList(); }
 };
 
 #endif /* SIMPLEDRAWLINE_HPP */
