@@ -22,7 +22,6 @@
 #include <QVariant>
 #include <QString>
 #include <QStringList>
-#include <QFont>
 #include <QList>
 #include <QDateTime>
 
@@ -80,7 +79,7 @@ public:
 
 	//! Get an HTML string to describe the object
 	//! @param core A pointer to the core
-	//! @flags a set of flags with information types to include.
+	//! @param flags a set of flags with information types to include.
 	QString getInfoString(const StelCore* core, const InfoStringGroup& flags) const override;
 	//! Return a map like StelObject::getInfoMap(), but with a few extra tags also available in getMap().
 	//! - sntype
@@ -96,7 +95,7 @@ public:
 	QString getEnglishName(void) const override;
 
 protected:
-	QString getMagnitudeInfoString(const StelCore *core, const InfoStringGroup& flags, const int decimals=1) const override;
+	QString getMagnitudeInfoString(const StelCore *core, const InfoStringGroup& flags, const int decimals=1, const float& magOffset=0.f) const override;
 
 private:
 	bool initialized;
