@@ -46,8 +46,8 @@ public:
 	//! shares the same parent)
 	TuiNodeInt(const QString& text, QObject* receiver, const char* method, int defValue, 
 		   int min, int max, int inc, TuiNode* parent=Q_NULLPTR, TuiNode* prev=Q_NULLPTR);
-	virtual TuiNodeResponse handleEditingKey(int key) Q_DECL_OVERRIDE;
-	virtual QString getDisplayText() const Q_DECL_OVERRIDE;
+	TuiNodeResponse handleEditingKey(int key) override;
+	QString getDisplayText() const override;
 
 signals:
 	void setValue(int b);
