@@ -22,9 +22,10 @@
 
 #include <QString>
 #include <QFile>
+#include <QMutex>
 
 //! @class StelLogger
-//! Class wit only static members used to manage logging for Stellarium.
+//! Class with only static members used to manage logging for Stellarium.
 //! The debugLogHandler() method allow to defined it as a standard Qt messages handler
 //! which is then used by qDebug, qWarning and qFatal.
 class StelLogger
@@ -39,7 +40,7 @@ public:
 	static void deinit();
 
 	//! Handler for qDebug() and friends. Writes message to log file at $USERDIR/log.txt and echoes to stderr.
-	static void debugLogHandler(QtMsgType, const QMessageLogContext&, const QString& str);
+	static void debugLogHandler(QtMsgType type, const QMessageLogContext& ctx, const QString& str);
 
 	//! Return a copy of text of the log file.
 	static const QString& getLog() {return log;}
@@ -55,8 +56,7 @@ public:
 private:
 	static QFile logFile;
 	static QString log;
-	
-	static QString getMsvcVersionString(int ver);
+	static QMutex fileMutex;
 };
 
 #endif // STELLOGGER_HPP
