@@ -20,6 +20,7 @@
 #include "StelLocaleMgr.hpp"
 #include "StelApp.hpp"
 #include "StelUtils.hpp"
+#include "StelSkyCultureMgr.hpp"
 
 #include <QLocale>
 #include <QDebug>
@@ -48,8 +49,11 @@ void StelLocaleMgr::init()
 	QSettings* conf = StelApp::getInstance().getSettings();
 	Q_ASSERT(conf);
 
-	setSkyLanguage(conf->value("localization/sky_locale", "system").toString(), false);
+#ifdef ENABLE_NLS
 	setAppLanguage(conf->value("localization/app_locale", "system").toString(), false);
+#else
+	setAppLanguage("en", false);
+#endif
 
 	timeFormat = stringToSTimeFormat(conf->value("localization/time_display_format", "system_default").toString());
 	dateFormat = stringToSDateFormat(conf->value("localization/date_display_format", "system_default").toString());
@@ -64,11 +68,23 @@ void StelLocaleMgr::setAppLanguage(const QString& newAppLanguageName, bool refre
 	Q_ASSERT(StelTranslator::globalTranslator);
 	delete StelTranslator::globalTranslator;
 	StelTranslator::globalTranslator = new StelTranslator("stellarium", newAppLanguageName);
-	qDebug().noquote() << "Application language:" << StelTranslator::globalTranslator->getTrueLocaleName();
+	qInfo().noquote() << "Application language:" << StelTranslator::globalTranslator->getTrueLocaleName();
+
+	// Update the translator with new locale name
+	skyTranslator.reset(new StelSkyTranslator(newAppLanguageName));
+	qInfo().noquote() << "Sky language:" << skyTranslator->getTrueLocaleName();
+
+	// Update the translator with new locale name
+	planetaryFeaturesTranslator.reset(new StelTranslator("stellarium-planetary-features", newAppLanguageName));
+	qInfo().noquote() << "Planetary features language:" << planetaryFeaturesTranslator->getTrueLocaleName();
 
 	// Update the translator with new locale name
 	scriptsTranslator.reset(new StelTranslator("stellarium-scripts", newAppLanguageName));
-	qDebug().noquote() << "Scripts language:" << scriptsTranslator->getTrueLocaleName();
+	qInfo().noquote() << "Scripts language:" << scriptsTranslator->getTrueLocaleName();
+
+	// Update the translator with new locale name
+	skyCultureDescriptionsTranslator.reset(new StelTranslator("stellarium-skycultures-descriptions", newAppLanguageName));
+	qInfo().noquote() << "Sky culture description language:" << skyCultureDescriptionsTranslator->getTrueLocaleName();
 
 	createNameLists();
 	if (refreshAll)
@@ -80,23 +96,6 @@ bool StelLocaleMgr::isAppRTL() const
 	return QString("ar fa ckb ug ur he yi").contains(getAppLanguage());
 }
 
-/*************************************************************************
- Set the sky language.
-*************************************************************************/
-void StelLocaleMgr::setSkyLanguage(const QString& newSkyLanguageName, bool refreshAll)
-{
-	// Update the translator with new locale name
-	skyTranslator.reset(new StelTranslator("stellarium-skycultures", newSkyLanguageName));
-	qDebug().noquote() << "Sky language:" << skyTranslator->getTrueLocaleName();
-
-	// Update the translator with new locale name
-	planetaryFeaturesTranslator.reset(new StelTranslator("stellarium-planetary-features", newSkyLanguageName));
-	qDebug().noquote() << "Planetary features language:" << planetaryFeaturesTranslator->getTrueLocaleName();
-
-	if (refreshAll)
-		StelApp::getInstance().updateI18n();
-}
-
 /*************************************************************************
  Get the language currently used for sky objects..
 *************************************************************************/
@@ -131,6 +130,11 @@ const StelTranslator& StelLocaleMgr::getScriptsTranslator() const
 	return *scriptsTranslator;
 }
 
+const StelTranslator& StelLocaleMgr::getSkyCultureDescriptionsTranslator() const
+{
+	return *skyCultureDescriptionsTranslator;
+}
+
 // Return the time in ISO 8601 format that is : %Y-%m-%d %H:%M:%S
 QString StelLocaleMgr::getISO8601TimeLocal(double JD, double utcOffsetHrs) const
 {
@@ -185,7 +189,7 @@ QString StelLocaleMgr::getPrintableDateLocal(double JD, double utcOffsetHrs) con
 			str = StelUtils::localeDateString(year, month, day, dayOfWeek);
 			break;
 		default:
-			qWarning() << "WARNING: unknown date format fallback to system default";
+			qWarning() << "Unknown date format fallback to system default";
 			str = StelUtils::localeDateString(year, month, day, dayOfWeek);
 	}
 	return str;
@@ -208,7 +212,7 @@ QString StelLocaleMgr::getPrintableTimeLocal(double JD, double utcOffsetHrs) con
 		case STime12h:
 			return t.toString("hh:mm:ss AP");
 		default:
-			qWarning() << "WARNING: unknown time format, fallback to system default";
+			qWarning() << "Unknown time format, fallback to system default";
 
 #if (QT_VERSION>=QT_VERSION_CHECK(5,14,0))
 			return t.toString(QLocale().dateFormat(QLocale::ShortFormat));
@@ -272,7 +276,7 @@ StelLocaleMgr::STimeFormat StelLocaleMgr::stringToSTimeFormat(const QString& tf)
 		{"24h", STime24h},
 		{"12h", STime12h}};
 	if (!map.contains(tf))
-		qWarning() << "WARNING: unrecognized time_display_format : " << tf << " system_default used.";
+		qWarning() << "Unrecognized time_display_format : " << tf << " system_default used.";
 	return map.value(tf, STimeSystemDefault);
 }
 
@@ -294,7 +298,7 @@ StelLocaleMgr::SDateFormat StelLocaleMgr::stringToSDateFormat(const QString& df)
 		{"wwddmmyyyy",     SDateWWDDMMYYYY},
 		{"wwyyyymmdd",     SDateWWYYYYMMDD}};
 	if (!map.contains(df))
-		qWarning() << "WARNING: unrecognized date_display_format : " << df << " system_default used.";
+		qWarning() << "Unrecognized date_display_format : " << df << " system_default used.";
 	return map.value(df, SDateSystemDefault);
 }
 
@@ -305,12 +309,21 @@ QString StelLocaleMgr::sDateFormatToString(SDateFormat df)
 		"mmddyyyy",
 		"ddmmyyyy",
 		"yyyymmdd",
-		"wwddmmyyyy",
+		"wwmmddyyyy",
 		"wwddmmyyyy",
 		"wwyyyymmdd"};
 	return dfmt[df];
 }
 
+QString StelLocaleMgr::getQtTimeFormatStr() const
+{
+	QStringList tfmt = {
+	        "HH:mm",
+	        "HH:mm",
+	        "hh:mm AP"};
+	return tfmt[timeFormat];
+}
+
 QString StelLocaleMgr::getQtDateFormatStr() const
 {
 	QStringList dfmt = {
