@@ -128,6 +128,9 @@ public:
 	//! Get the list of objects which was recently selected by the user.
 	const QList<StelObjectP>& getSelectedObject() const {return lastSelectedObjects;}
 
+	//! Get the last selected object.
+	StelObjectP getLastSelectedObject() const { return lastSelectedObject; }
+
 	//! Return the list objects of type "type" which was recently selected by the user.
 	//! @param type return only objects of the given type
 	QList<StelObjectP> getSelectedObject(const QString& type) const;
@@ -165,6 +168,10 @@ public:
 	//! If obj is Q_NULLPTR, returns a 1-element map [["found", false]]
 	static QVariantMap getObjectInfo(const StelObjectP obj);
 
+	//! Return a QString of narrative information about the object (calls obj->getNarration()).
+	//! If obj is Q_NULLPTR, returns an empty string.
+	static QString getObjectNarration(const StelObjectP obj);
+
 	//! Return a list of enabled fields (custom info strings)
 	StelObject::InfoStringGroup getCustomInfoStrings();
 
@@ -173,7 +180,6 @@ public:
 	QStringList getExtraInfoStrings(const StelObject::InfoStringGroup& flags) const;
 
 public slots:
-
 	//! @note These functions were copied over from StelObject. Given that setExtraInfoString is non-const and some functions where these methods are useful are const, we can use the StelObjectMgr as "carrier object".
 	//! Allow additions to the Info String. Can be used by plugins to show extra info for the selected object, or for debugging.
 	//! Hard-set this string group to a single str, or delete all messages when str==""
@@ -202,11 +208,15 @@ public slots:
 	{
 		objectPointerVisibility=b;
 		emit flagSelectedObjectPointerChanged(b);
-
 	}
 	//! Get whether a pointer is to be drawn over selected object.
 	bool getFlagSelectedObjectPointer(void) { return objectPointerVisibility; }
 
+	//! Play a narration for the currently selected object.
+	//! This is linked to a StelAction that can be assigned to a keyboard shortcut.
+	//! Calling this while speech output is active will stop speech output instead.
+	void narrate();
+
 signals:
 	//! Indicate that the selected StelObjects has changed.
 	//! @param action define if the user requested that the objects are added to the selection or just replace it
@@ -220,10 +230,12 @@ private:
 	QMap<QString, StelObjectModule*> typeToModuleMap;
 	QMap<QString, QString> objModulesMap;
 
-	// The last selected object in stellarium
+	// The list of last selected objects in Stellarium
 	QList<StelObjectP> lastSelectedObjects;
 	// Should selected object pointer be drawn
 	bool objectPointerVisibility;
+	// The last selected object in Stellarium
+	StelObjectP lastSelectedObject;
 
 	//! Find in a "clever" way an object from its equatorial J2000.0 position.
 	StelObjectP cleverFind(const StelCore* core, const Vec3d& pos) const;
