@@ -144,9 +144,7 @@ void ToastTile::prepareDraw(Vec3f color)
 
 	if (core->getUseAberration())
 	{
-		Vec3d vel=core->getCurrentPlanet()->getHeliocentricEclipticVelocity();
-		vel=StelCore::matVsop87ToJ2000*vel;
-		vel*=core->getAberrationFactor() * (AU/(86400.0*SPEED_OF_LIGHT));
+		const Vec3d vel = core->getAberrationVec(core->getJDE());
 		vertexArray=QVector<Vec3d>(originalVertexArray);
 		for (int i=0; i<originalVertexArray.size(); i++)
 		{
