@@ -42,10 +42,6 @@ typedef void (*posFuncType)(double, double*, double*, void*);
 
 typedef void (OsculatingFunctType)(double jde0,double jde,double xyz[3], double xyzdot[3]);
 
-// epoch J2000: 12 UT on 1 Jan 2000
-#define J2000 2451545.0
-#define ORBIT_SEGMENTS 360
-
 class Orbit;
 class KeplerOrbit;
 class StelFont;
@@ -149,6 +145,9 @@ public:
 	};
 	Q_ENUM(PositionQuality)
 
+	// epoch J2000: 12 UT on 1 Jan 2000
+	static inline constexpr double J2000 = 2451545.0;
+
 public:
 	Planet(const QString& englishName,
 	       double equatorialRadius,
@@ -162,7 +161,7 @@ public:
 	       const QString& objModelName,
 	       posFuncType _coordFunc,
 	       Orbit *anOrbitPtr,
-	       OsculatingFunctType *osculatingFunc,
+	       OsculatingFunctType *osculFunc,
 	       bool closeOrbit,
 	       bool hidden,
 	       bool hasAtmosphere,
@@ -190,7 +189,7 @@ public:
 	//! @note subclasses should prefer to override only the component infostrings getInfoString...(), not this method!
 	//! @param core the StelCore object
 	//! @param flags a set of InfoStringGroup items to include in the return value.
-	//! @return a QString containing an HMTL encoded description of the Planet.
+	//! @return a QString containing an HTML encoded description of the Planet.
 	QString getInfoString(const StelCore *core, const InfoStringGroup& flags) const override;
 	//! In addition to the entries from StelObject::getInfoMap(), Planet objects provide
 	//! - phase (result of getPhase)
@@ -228,6 +227,8 @@ public:
 	//! - distance (distance to object; for Solar system objects only; A.U.)
 	//! - distance-km (distance to object; for Solar system objects only; kilometers)
 	QVariantMap getInfoMap(const StelCore *core) const  override;
+	//! Return a textual description ready for speech output
+	QString getNarration(const StelCore *core, const InfoStringGroup& flags=StelObject::AllInfo) const override;
 	double getCloseViewFov(const StelCore* core) const override;
 	double getSatellitesFov(const StelCore* core) const override;
 	double getParentSatellitesFov(const StelCore* core) const override;
@@ -256,13 +257,28 @@ public:
 	//! The end result is a non-normalized 3D vector which allows retrieving distances etc.
 	//! The positional computation is called by SolarSystem. If the core's aberration setting is active, the J2000 position will then include it.
 	Vec3d getJ2000EquatorialPos(const StelCore *core) const override;
-	QString getEnglishName(void) const override;
-	QString getNameI18n(void) const override;
+	QString getEnglishName(void) const override {return englishName;}
+	QString getNameI18n(void) const override {return nameI18;}
+
 	virtual QString getIAUDesignation(void) const;
-	QString getNativeName(void) const { return nativeName; }
-	QString getNativeNameI18n(void) const { return nativeNameMeaningI18n; }
-	QString getCommonEnglishName(void) const {return englishName;}
-	QString getCommonNameI18n(void) const {return nameI18;}
+	QString getNameNative(void) const override { return (culturalNames.isEmpty() ? "" : culturalNames.constFirst().native); }
+	QString getNameNativeI18n(void) const { return (culturalNames.isEmpty() ? "" : culturalNames.constFirst().translatedI18n); }
+
+	// NEW Skyculture-related names
+	//! retrieve pronunciation from the first of the cultural names
+	QString getNamePronounce() const override {return (culturalNames.empty() ? "" : culturalNames.constFirst().pronounceI18n);}
+	//! Combine screen label from various components, depending on settings in SkyCultureMgr
+	QString getScreenLabel() const override;
+	//! Combine InfoString label from various components, depending on settings in SkyCultureMgr
+	QString getInfoLabel() const override;
+	//! Underlying worker that processes the culturalNames
+	QStringList getCultureLabels(StelObject::CulturalDisplayStyle style) const;
+	void removeAllCulturalNames() { culturalNames.clear();}
+	//! Add a name for the currently set skyculture
+	void addCulturalName(StelObject::CulturalName culturalName){culturalNames.append(culturalName);}
+
+
+
 	//! Get angular semidiameter, degrees. If planet display is artificially enlarged (e.g. Moon upscale), value will also be increased.
 	double getAngularRadius(const StelCore* core) const override;
 	virtual bool hasAtmosphere(void) {return atmosphere;}
@@ -319,9 +335,6 @@ public:
 	PlanetType getPlanetType() const {return pType;}
 	Orbit* getOrbit() const {return orbitPtr;}
 
-	void setNativeName(QString planet) { nativeName = planet; }
-	void setNativeNameMeaning(QString planet) { nativeNameMeaning = planet; }
-
 	//! set the IAU moon number (designation of the moon), if any.
 	void setIAUMoonNumber(const QString& designation);
 
@@ -342,8 +355,6 @@ public:
 	double getMass() const { return massKg; }
 	//
 	static ApparentMagnitudeAlgorithm getApparentMagnitudeAlgorithm()  { return vMagAlgorithm; }
-	static const QString getApparentMagnitudeAlgorithmString()  { return vMagAlgorithmMap.value(vMagAlgorithm); }
-	static void setApparentMagnitudeAlgorithm(QString algorithm);
 	static void setApparentMagnitudeAlgorithm(ApparentMagnitudeAlgorithm algorithm){ vMagAlgorithm=algorithm; }
 
 	//! Compute the axial z rotation (daily rotation around the polar axis) [degrees] to use from equatorial to hour angle based coordinates.
@@ -396,10 +407,12 @@ public:
 	double getRotObliquity(double JDE) const;
 
 	//! Compute the position and orbital velocity in the parent Planet coordinate system and set aberrationPush
+	//! In case of the Sun, it is the heliocentric position and velocity so zeros are set
 	//! Does not compute new position when dateJDE is less than deltaJDE away from lastJDE
 	//! You can add the aberrationPush value according to Edot*lightTime in Explanatory Supplement (2013) formula 7.55.
 	virtual void computePosition(const StelObserver *observer, const double dateJDE, const Vec3d &aberrationPush);
 	//! Compute the position and orbital velocity in the parent Planet coordinate system, and return them in eclPosition and eclVelocity
+	//! In case of the Sun, it is the heliocentric position and velocity so zeros are set
 	//! These may be preferred when we want to avoid setting the actual position (e.g., RTS computation)
 	virtual void computePosition(const double dateJDE, Vec3d &eclPosition, Vec3d &eclVelocity) const;
 
@@ -431,8 +444,15 @@ public:
 	double getPhaseAngle(const Vec3d& obsPos) const;
 	//! Check whether the planet is in a waning phase, i.e. its phase angle is increasing
 	bool isWaning(const Vec3d& observerPosition, const Vec3d& observerVelocity) const;
-	//! Get the elongation angle (radians) for an observer at pos obsPos in heliocentric coordinates (in AU)
+	//! Get the elongation angle (angular distance, radians, 0<e<2pi) for an observer at pos obsPos in heliocentric coordinates (in AU)
 	double getElongation(const Vec3d& obsPos) const;
+	//! Get the elongation angle from the Sun in terms of difference in ecliptical longitude (radians) from the Sun.
+	//! Result e is within [0...2pi[ :
+	//! - A result <pi implies eastern elongation, evening visibility.
+	//! - A result pi<e<2pi implies western elongation, morning visibility.
+	//! Calling this for the Sun returns 0.
+	double getElongationDLambda() const;
+
 	//! Get the angular radius (degrees) of the planet spheroid (i.e. without the rings)
 	double getSpheroidAngularRadius(const StelCore* core) const;
 	//! Get the planet phase (illuminated fraction of the planet disk, [0=dark..1=full]) for an observer at pos obsPos in heliocentric coordinates (in AU)
@@ -478,6 +498,9 @@ public:
 	Vec3d getHeliocentricEclipticPos() const {return getHeliocentricPos(eclipticPos);}
 	Vec3d getHeliocentricEclipticPos(double dateJDE) const;
 
+	//! Return the barycentric ecliptical position
+	Vec3d getBarycentricEclipticPos(double dateJDE) const;
+
 	//! Return the heliocentric transformation for local (parentocentric) coordinate
 	//! @arg p planetocentric rectangular ecliptical coordinate (J2000)
 	//! @return heliocentric rectangular ecliptical coordinates (J2000)
@@ -489,9 +512,12 @@ public:
 	//! Get the planet velocity around the parent planet in ecliptical coordinates in AU/d
 	Vec3d getEclipticVelocity() const {return eclipticVelocity;}
 
-	//! Get the planet's heliocentric velocity in the solar system in ecliptical coordinates in AU/d. Required for aberration!
+	//! Get the planet's heliocentric velocity in the solar system in ecliptical coordinates in AU/d.
 	Vec3d getHeliocentricEclipticVelocity() const;
 
+	//! Return the barycentric ecliptical velocity in the solar system in ecliptical coordinates in AU/d. Required for aberration!
+	Vec3d getBarycentricEclipticVelocity(double dateJDE) const;
+
 	//! Compute and return the distance to the given position in heliocentric ecliptical (J2000) coordinates (in AU)
 	//! Preserves result for later retrieval by getDistance()
 	//! As side effect, improve fps by juggling update frequency (deltaJDE) for asteroids and other minor bodies. They must be fast if close to observer, but can be slow if further away.
@@ -518,10 +544,6 @@ public:
 	void setFlagLabels(bool b){flagLabels = b;}
 	bool getFlagLabels(void) const {return flagLabels;}
 
-	bool flagNativeName;
-	void setFlagNativeName(bool b) { flagNativeName = b; }
-	bool getFlagNativeName(void) const { return flagNativeName; }
-
 	///////////////////////////////////////////////////////////////////////////
 	///// Orbit related code
 	// Should move to an OrbitPath class which works on a SolarSystemObject, not a Planet
@@ -530,6 +552,8 @@ public:
 	LinearFader orbitFader;
 	// draw orbital path of Planet
 	void drawOrbit(const StelCore*);
+
+	static constexpr int ORBIT_SEGMENTS = 360;
 	Vec3d orbit[ORBIT_SEGMENTS+1];  // store heliocentric coordinates for drawing the orbit
 	double deltaJDE;                // time difference between positional updates.
 	double deltaOrbitJDE;
@@ -644,9 +668,13 @@ public:
 	//!       *   +40 for objects with no set time on current date.
 	Vec4d getRTSTime(const StelCore* core, const double altitude=0.) const override;
 
+	//! Reset planet textures to those defined at start time. (You may load other textures with replaceTexture()
 	void resetTextures();
+	//! Use texture from @param texName (must reside inside the scripts directory!)
 	void replaceTexture(const QString& texName);
-	
+
+	void setSurvey(const HipsSurveyP& colors, const HipsSurveyP& normals, const HipsSurveyP& horizons);
+
 protected:
 	// These components for getInfoString() can be overridden in subclasses
 	virtual QString getInfoStringName(const StelCore *core, const InfoStringGroup& flags) const;
@@ -738,78 +766,83 @@ protected:
 
 	PlanetOBJModel* loadObjModel() const;
 
-	QString englishName;             // english planet name
-	QString nameI18;                 // International translated name
-	QString nativeName;              // Can be used in a skyculture
-	QString nativeNameMeaning;       // Can be used in a skyculture
-	QString nativeNameMeaningI18n;   // Can be used in a skyculture
-	QString texMapName;              // Texture file path
-	QString normalMapName;           // Texture file path
-	QString horizonMapName;          // Texture file path
-	RotationElements re;             // Rotation and axis orientation parameters
-	double siderealPeriod;           // sidereal period (Planet year or a moon's sidereal month) [earth days]
-	double equatorialRadius;         // Planet's equatorial radius in AU
-	double oneMinusOblateness;       // OneMinusOblateness=(polar radius)/(equatorial radius). Geometric flattening f=1-oneMinusOblateness (ExplanSup2013 10.1)
-	Vec3d eclipticPos;               // Position in AU in the rectangular ecliptic coordinate system (J2000) centered on the parent body.
-	                                 // To get heliocentric coordinates, use getHeliocentricEclipticPos()
-	Vec3d eclipticVelocity;          // Speed in AU/d in the rectangular ecliptic coordinate system (J2000) around the parent body.
-	                                 // NEW FEATURE in late 2017. For now, this may be 0/0/0 when we are not yet able to compute it.
-	                                 // to get velocity, preferably read getEclipticVelocity() and getHeliocentricEclipticVelocity()
-	                                 // The "State Vector" [Heafner 1999] can be formed from (JDE, eclipticPos, eclipticVelocity)
-	Vec3d aberrationPush;            // 0.21.2+: a small displacement to be applied if aberred positions are requested.
-	Vec3d screenPos;                 // Used to store temporarily the 2D position on screen. We need double for moons. Observe Styx from Pluto w/o atmosphere to see that.
-	Vec3f haloColor;                 // used for drawing the planet halo. Also, when non-spherical (OBJ) model without texture is used, its color is derived from haloColour*albedo.
+	QString englishName;             //!< english planet name
+	QString nameI18;                 //!< International translated name
+	QString texMapName;              //!< Texture file path
+	QString normalMapName;           //!< Texture file path
+	QString horizonMapName;          //!< Texture file path
+	RotationElements re;             //!< Rotation and axis orientation parameters
+	double siderealPeriod;           //!< sidereal period (Planet year or a moon's sidereal month) [earth days]
+	double equatorialRadius;         //!< Planet's equatorial radius in AU
+	double oneMinusOblateness;       //!< OneMinusOblateness=(polar radius)/(equatorial radius). Geometric flattening f=1-oneMinusOblateness (ExplanSup2013 10.1)
+	Vec3d eclipticPos;               //!< Position in AU in the rectangular ecliptic coordinate system (J2000) centered on the parent body.
+					 //!< To get heliocentric coordinates, use getHeliocentricEclipticPos()
+	Vec3d eclipticVelocity;          //!< Speed in AU/d in the rectangular ecliptic coordinate system (J2000) around the parent body.
+					 //!< NEW FEATURE in late 2017. For now, this may be 0/0/0 when we are not yet able to compute it.
+					 //!< to get velocity, preferably read getEclipticVelocity() and getHeliocentricEclipticVelocity()
+					 //!< The "State Vector" [Heafner 1999] can be formed from (JDE, eclipticPos, eclipticVelocity)
+	Vec3d aberrationPush;            //!< 0.21.2+: a small displacement to be applied if aberred positions are requested.
+	Vec3d screenPos;                 //!< Used to store temporarily the 2D position on screen. We need double for moons. Observe Styx from Pluto w/o atmosphere to see that.
+	Vec3f haloColor;                 //!< used for drawing the planet halo. Also, when non-spherical (OBJ) model without texture is used, its color is derived from haloColour*albedo.
 
-	float absoluteMagnitude;         // since 2017 this moved to the Planet class: V(1,0) from Explanatory Supplement or WGCCRE2009 paper for the planets, H in the H,G magnitude system for Minor planets, H10 for comets.
-	                                 // This is the apparent visual magnitude when 1AU from sun and observer, with zero phase angle.
-	double massKg;                   // 23.1+: mass of the planet in kg
-	float albedo;                    // Planet albedo. Used for magnitude computation when no other formula in use. Also, when non-spherical (OBJ) model without texture is used, its color is derived from haloColour*albedo.
-	float roughness;                 // Oren-Nayar roughness for Moon and OBJ-based models
-	float outgas_intensity;          // The intensity of a pseudo-outgas effect, based on an inverse exponential Lambert shading, with the light at the viewing position
-	                                 // Non-null only for Comets, but we use one shader for all Planets and derivatives, so we need a placeholder here.
-	float outgas_falloff;            // Exponent for falloff of outgas effect, should probably be < 1
-	                                 // Non-null only for Comets, but we use one shader for all Planets and derivatives, so we need a placeholder here.
-	Mat4d rotLocalToParent;          // retro-documented:
-	                                 // rotation matrix of axis orientation with respect to the rotation axes of the parent body.
-	                                 // For planets, this is the axis orientation w.r.t. VSOP87A/J2000 ecliptical system.
-	                                 // For planets' satellites, this used to be a rotation into the planet's equatorial system.
-	                                 // 0.21+: if rot_pole... data available in ssystem_*.ini (and therefore re.method==WGCCRE), this is not the rotation from planet axes over ICRF to the VSOP frame on which Stellarium is defined.
-	                                 //
-	float axisRotation;              // Rotation angle of the Planet on its axis, degrees.
-	                                 // For Earth, this should be Greenwich Mean Sidereal Time GMST.
-	                                 // For V0.21+, and for planets computed after the IAU2009/WGCCRE papers this is angle W (rotDeg),
-	                                 // i.e. angle between ascending node of body equator w.r.t. ICRF equator and its prime meridian.
-	StelTextureSP texMap;            // Planet map texture
-	StelTextureSP normalMap;         // Planet normal map texture
-	StelTextureSP horizonMap;        // Planet horizon map texture
+	float absoluteMagnitude;         //!< since 2017 this moved to the Planet class: V(1,0) from Explanatory Supplement or WGCCRE2009 paper for the planets, H in the H,G magnitude system for Minor planets, H10 for comets.
+					 //!< This is the apparent visual magnitude when 1AU from sun and observer, with zero phase angle.
+	double massKg;                   //!< 23.1+: mass of the planet in kg
+	float albedo;                    //!< Planet albedo. Used for magnitude computation when no other formula in use. Also, when non-spherical (OBJ) model without texture is used, its color is derived from haloColour*albedo.
+	float roughness;                 //!< Oren-Nayar roughness for Moon and OBJ-based models
+	float outgas_intensity;          //!< The intensity of a pseudo-outgas effect, based on an inverse exponential Lambert shading, with the light at the viewing position
+					 //!< Non-null only for Comets, but we use one shader for all Planets and derivatives, so we need a placeholder here.
+	float outgas_falloff;            //!< Exponent for falloff of outgas effect, should probably be < 1
+					 //!< Non-null only for Comets, but we use one shader for all Planets and derivatives, so we need a placeholder here.
+	Mat4d rotLocalToParent;          //!< retro-documented:
+					 //!< rotation matrix of axis orientation with respect to the rotation axes of the parent body.
+					 //!< For planets, this is the axis orientation w.r.t. VSOP87A/J2000 ecliptical system.
+					 //!< For planets' satellites, this used to be a rotation into the planet's equatorial system.
+					 //!< 0.21+: if rot_pole... data available in ssystem_*.ini (and therefore re.method==WGCCRE), this is not the rotation from planet axes over ICRF to the VSOP frame on which Stellarium is defined.
+					 //!<
+	float axisRotation;              //!< Rotation angle of the Planet on its axis, degrees.
+					 //!< For Earth, this should be Greenwich Mean Sidereal Time GMST.
+					 //!< For V0.21+, and for planets computed after the IAU2009/WGCCRE papers this is angle W (rotDeg),
+					 //!< i.e. angle between ascending node of body equator w.r.t. ICRF equator and its prime meridian.
+	StelTextureSP texMap;            //!< Planet map texture
+	StelTextureSP normalMap;         //!< Planet normal map texture
+	StelTextureSP horizonMap;        //!< Planet horizon map texture
 
-	PlanetOBJModel* objModel;               // Planet model (when it has been loaded)
-	QFuture<PlanetOBJModel*>* objModelLoader;// For async loading of the OBJ file
+	PlanetOBJModel* objModel;                 //!< Planet model (when it has been loaded)
+	QFuture<PlanetOBJModel*>* objModelLoader; //!< For async loading of the OBJ file
 	QString objModelPath;
 
-	HipsSurveyP survey;
+	struct SurveyPack
+	{
+		HipsSurveyP colors;
+		HipsSurveyP normals;
+		HipsSurveyP horizons;
+		operator bool() const { return !!colors; }
+	};
 
-	Ring* rings;                     // Planet rings
-	double distance;                 // Temporary variable used to store the distance to a given point
-	                                 // it is used for sorting while drawing
-	double sphereScale;              // Artificial scaling for better viewing.
-	double lastJDE;                  // caches JDE of last positional computation
+	SurveyPack survey;
 
-	posFuncType coordFunc;           // callback for the calculation of the equatorial rectangular heliocentric position at time JDE.
-	Orbit* orbitPtr;                 // Usually a KeplerOrbit for positional computations of Minor Planets, Comets and Moons.
-	                                 // For an "observer", it is GimbalOrbit.
-	                                 // For the major planets, it is Q_NULLPTR.
+	Ring* rings;                     //!< Planet rings
+	double distance;                 //!< Temporary variable used to store the distance to a given point
+					 //!< it is used for sorting while drawing
+	double sphereScale;              //!< Artificial scaling for better viewing.
+	double lastJDE;                  //!< caches JDE of last positional computation
+
+	posFuncType coordFunc;           //!< callback for the calculation of the equatorial rectangular heliocentric position at time JDE.
+	Orbit* orbitPtr;                 //!< Usually a KeplerOrbit for positional computations of Minor Planets, Comets and Moons.
+					 //!< For an "observer", it is GimbalOrbit.
+					 //!< For the major planets, it is Q_NULLPTR.
 
 	OsculatingFunctType *const osculatingFunc;
-	QSharedPointer<Planet> parent;           // Planet parent i.e. sun for earth
-	QList<QSharedPointer<Planet> > satellites;      // satellites of the Planet
+	QSharedPointer<Planet> parent;                  //!< Planet parent i.e. sun for earth
+	QList<QSharedPointer<Planet> > satellites;      //!< satellites of the Planet
 	LinearFader hintFader;
-	LinearFader labelsFader;         // Store the current state of the label for this planet
-	bool flagLabels;                 // Define whether labels should be displayed
-	bool hidden;                     // useful for fake planets used as observation positions - not drawn or labeled
-	bool atmosphere;                 // Does the planet have an atmosphere?
-	bool halo;                       // Does the planet have a halo?
-	PlanetType pType;                // Type of body
+	LinearFader labelsFader;         //!< Store the current state of the label for this planet
+	bool flagLabels;                 //!< Define whether labels should be displayed
+	bool hidden;                     //!< useful for fake planets used as observation positions - not drawn or labeled
+	bool atmosphere;                 //!< Does the planet have an atmosphere?
+	bool halo;                       //!< Does the planet have a halo?
+	PlanetType pType;                //!< Type of body
 	bool multisamplingEnabled_;
 	bool planetShadowsSupersampEnabled_;
 
@@ -818,27 +851,28 @@ protected:
 	QOpenGLFunctions* gl;
 
 	static Vec3f labelColor;
-	static StelTextureSP hintCircleTex; // The circle around an SSO
-	static const QMap<PlanetType, QString> pTypeMap; // Maps fast type to english name.
-	static const QMap<QString, QString> nPlanetMap; // Maps fast IAU number to IAU designation.
-	static const QMap<ApparentMagnitudeAlgorithm, QString> vMagAlgorithmMap;
+	static StelTextureSP hintCircleTex;              //!< The circle around an SSO
+	static const QMap<PlanetType, QString> pTypeMap; //!< Maps fast type to english name.
+	static const QMap<QString, QString> nPlanetMap;  //!< Maps fast IAU number to IAU designation.
 	static bool drawMoonHalo;
 	static bool drawSunHalo;
 	//! If true, planet orbits will be drawn even if planet is off screen.
 	static bool permanentDrawingOrbits;
 	static int orbitsThickness;
+	QString discoverer;    //!< Discovery data
+	QString discoveryDate; //!< Discovery data
 
 private:
 	class StelPropertyMgr* propMgr;
 	QString iauMoonNumber;
 	float b_v;
-	// Discovery data
-	QString discoverer;
-	QString discoveryDate;
-	// File path for texture and normal map; both variables used for saving original names of files
-	QString texMapFileOrig;
-	QString normalMapFileOrig;
-	QString horizonMapFileOrig;
+
+	QList<StelObject::CulturalName> culturalNames; //!< names loaded from non-modern Skycultures. Usually just one, but there may be more!
+
+
+	QString texMapFileOrig;     //!< File path for texture; used for saving original filename
+	QString normalMapFileOrig;  //!< File path for normal map; used for saving original filename
+	QString horizonMapFileOrig; //!< File path for horizon map; used for saving original filename
 
 	std::unique_ptr<QOpenGLVertexArrayObject> sphereVAO;
 	std::unique_ptr<QOpenGLVertexArrayObject> ringsVAO;
@@ -882,6 +916,8 @@ private:
 		int eclipsePush; // apparent brightness push for partial Lunar Eclipse (make bright rim overbright)
 		int normalMap;
 		int horizonMap;
+		int hasNormalMap;
+		int hasHorizonMap;
 
 		// Rings-specific variables
 		int isRing;
@@ -909,7 +945,8 @@ private:
 	};
 
 	//! Calculates and uploads the common shader uniforms (projection matrix, texture, lighting&shadow data)
-	RenderData setCommonShaderUniforms(const StelPainter &painter, QOpenGLShaderProgram* shader, const PlanetShaderVars& shaderVars); // const;
+	RenderData setCommonShaderUniforms(const StelPainter &painter, QOpenGLShaderProgram* shader,
+	                                   const PlanetShaderVars& shaderVars, bool hasNormalMap, bool hasHorizonMap);
 
 	static PlanetShaderVars planetShaderVars;
 	static QOpenGLShaderProgram* planetShaderProgram;
