@@ -30,9 +30,8 @@
 #include "Planet.hpp"
 #include "StelHips.hpp"
 
-#include <QFont>
-
 class Orbit;
+class StelSkyCulture;
 class StelTranslator;
 class StelObject;
 class StelCore;
@@ -61,7 +60,6 @@ class SolarSystem : public StelObjectModule, protected QOpenGLFunctions
 	Q_PROPERTY(bool flagHints			READ getFlagHints			WRITE setFlagHints			NOTIFY flagHintsChanged)
 	Q_PROPERTY(bool flagMarkers			READ getFlagMarkers			WRITE setFlagMarkers			NOTIFY markersDisplayedChanged)
 	Q_PROPERTY(bool flagPointer			READ getFlagPointer			WRITE setFlagPointer			NOTIFY flagPointerChanged)
-	Q_PROPERTY(bool flagNativePlanetNames		READ getFlagNativePlanetNames		WRITE setFlagNativePlanetNames		NOTIFY flagNativePlanetNamesChanged)
 	Q_PROPERTY(bool planetsDisplayed		READ getFlagPlanets			WRITE setFlagPlanets			NOTIFY flagPlanetsDisplayedChanged)
 	Q_PROPERTY(bool flagOrbits			READ getFlagOrbits			WRITE setFlagOrbits			NOTIFY flagOrbitsChanged)
 	Q_PROPERTY(bool flagPlanetsOrbits		READ getFlagPlanetsOrbits		WRITE setFlagPlanetsOrbits		NOTIFY flagPlanetsOrbitsChanged)
@@ -187,9 +185,9 @@ public:
 	QList<StelObjectP> searchAround(const Vec3d& v, double limitFov, const StelCore* core) const override;
 
 	//! Search for a SolarSystem object based on the localised name.
-	//! @param nameI18n the case in-sensitive translated planet name.
+	//! @param planetNameI18n the case in-sensitive translated planet name.
 	//! @return a StelObjectP for the object if found, else Q_NULLPTR.
-	StelObjectP searchByNameI18n(const QString& nameI18n) const override;
+	StelObjectP searchByNameI18n(const QString& planetNameI18n) const override;
 
 	//! Search for a SolarSystem object based on the English name.
 	//! @param name the case in-sensitive English planet name.
@@ -265,7 +263,7 @@ public slots:
 	//! Set the amount of planet labels. The real amount is also proportional with FOV.
 	//! The limit is set in function of the planets magnitude
 	//! @param a the amount between 0 and 10. 0 is no labels, 10 is maximum of labels
-	void setLabelsAmount(double a) {if(!fuzzyEquals(a, labelsAmount)) {labelsAmount=a; emit labelsAmountChanged(a);}}
+	void setLabelsAmount(double a) {if(!fuzzyEquals(a, labelsAmount)) {labelsAmount=a; StelApp::immediateSave("astro/labels_amount", a); emit labelsAmountChanged(a);}}
 	//! Get the amount of planet labels. The real amount is also proportional with FOV.
 	//! @return the amount between 0 and 10. 0 is no labels, 10 is maximum of labels
 	double getLabelsAmount(void) const {return labelsAmount;}
@@ -276,7 +274,7 @@ public slots:
 	bool getFlagOrbits() const {return flagOrbits;}
 
 	//! Set flag which determines if the planet pointer (red cross) is drawn or hidden on a selected planet.
-	void setFlagPointer(bool b) { if (b!=flagPointer) { flagPointer=b; emit flagPointerChanged(b); }}
+	void setFlagPointer(bool b) { if (b!=flagPointer) { flagPointer=b; StelApp::immediateSave("astro/flag_planets_pointers", b); emit flagPointerChanged(b); }}
 	//! Get the current value of the flag which determines if planet pointers are drawn or hidden.
 	bool getFlagPointer() const { return flagPointer;}
 
@@ -287,7 +285,7 @@ public slots:
 	bool getFlagLightTravelTime(void) const {return flagLightTravelTime;}
 
 	//! Set flag whether to use OBJ models for rendering, where available
-	void setFlagUseObjModels(bool b) { if(b!=flagUseObjModels) { flagUseObjModels = b; emit flagUseObjModelsChanged(b); } }
+	void setFlagUseObjModels(bool b) { if(b!=flagUseObjModels) { flagUseObjModels = b; StelApp::immediateSave("astro/flag_use_obj_models", b); emit flagUseObjModelsChanged(b); } }
 	//! Get the current value of the flag which determines whether to use OBJ models for rendering, where available
 	bool getFlagUseObjModels(void) const { return flagUseObjModels; }
 
@@ -303,8 +301,9 @@ public slots:
 	//! Set the color used to draw planet labels.
 	//! @param c The color of the planet labels (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setLabelsColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setLabelsColor(c.toVec3f());
 	//! @endcode
 	void setLabelsColor(const Vec3f& c);
 	//! Get the current color used to draw planet labels.
@@ -314,8 +313,9 @@ public slots:
 	//! Set the color used to draw solar system object orbit lines.
 	//! @param c The color of the solar system object orbit lines (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setOrbitsColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setOrbitsColor(c.toVec3f());
 	//! @endcode
 	void setOrbitsColor(const Vec3f& c);
 	//! Get the current color used to draw solar system object orbit lines.
@@ -325,8 +325,9 @@ public slots:
 	//! Set the color used to draw orbits lines of the major planets.
 	//! @param c The color of orbits lines of the major planets (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setMajorPlanetsOrbitsColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setMajorPlanetsOrbitsColor(c.toVec3f());
 	//! @endcode
 	void setMajorPlanetsOrbitsColor(const Vec3f& c);
 	//! Get the current color used to draw orbits lines of the major planets.
@@ -336,8 +337,9 @@ public slots:
 	//! Set the color used to draw orbits lines of moons of planets.
 	//! @param c The color of orbits lines of moons of planets lines (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setMoonsOrbitsColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setMoonsOrbitsColor(c.toVec3f());
 	//! @endcode
 	void setMoonsOrbitsColor(const Vec3f& c);
 	//! Get the current color used to draw orbits lines of moons of planets.
@@ -347,8 +349,9 @@ public slots:
 	//! Set the color used to draw orbits lines of the minor planets.
 	//! @param c The color of orbits lines of the minor planets (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setMinorPlanetsOrbitsColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setMinorPlanetsOrbitsColor(c.toVec3f());
 	//! @endcode
 	void setMinorPlanetsOrbitsColor(const Vec3f& c);
 	//! Get the current color used to draw orbits lines of the minor planets.
@@ -358,8 +361,9 @@ public slots:
 	//! Set the color used to draw orbits lines of the dwarf planets.
 	//! @param c The color of orbits lines of the dwarf planets (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setDwarfPlanetsOrbitsColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setDwarfPlanetsOrbitsColor(c.toVec3f());
 	//! @endcode
 	void setDwarfPlanetsOrbitsColor(const Vec3f& c);
 	//! Get the current color used to draw orbits lines of the dwarf planets.
@@ -369,8 +373,9 @@ public slots:
 	//! Set the color used to draw orbits lines of cubewanos.
 	//! @param c The color of orbits lines of cubewanos (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setCubewanosOrbitsColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setCubewanosOrbitsColor(c.toVec3f());
 	//! @endcode
 	void setCubewanosOrbitsColor(const Vec3f& c);
 	//! Get the current color used to draw orbits lines of cubewanos.
@@ -380,8 +385,9 @@ public slots:
 	//! Set the color used to draw orbits lines of plutinos.
 	//! @param c The color of orbits lines of plutinos (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setPlutinosOrbitsColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setPlutinosOrbitsColor(c.toVec3f());
 	//! @endcode
 	void setPlutinosOrbitsColor(const Vec3f& c);
 	//! Get the current color used to draw orbits lines of plutinos.
@@ -391,8 +397,9 @@ public slots:
 	//! Set the color used to draw orbits lines of scattered disk objects.
 	//! @param c The color of orbits lines of scattered disk objects (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setScatteredDiskObjectsOrbitsColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setScatteredDiskObjectsOrbitsColor(c.toVec3f());
 	//! @endcode
 	void setScatteredDiskObjectsOrbitsColor(const Vec3f& c);
 	//! Get the current color used to draw orbits lines of scattered disk objects.
@@ -402,8 +409,9 @@ public slots:
 	//! Set the color used to draw orbits lines of Oort cloud objects.
 	//! @param c The color of orbits lines of Oort cloud objects (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setOortCloudObjectsOrbitsColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setOortCloudObjectsOrbitsColor(c.toVec3f());
 	//! @endcode
 	void setOortCloudObjectsOrbitsColor(const Vec3f& c);
 	//! Get the current color used to draw orbits lines of Oort cloud objects.
@@ -413,8 +421,9 @@ public slots:
 	//! Set the color used to draw comet orbit lines.
 	//! @param c The color of the comet orbit lines (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setCometsOrbitsColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setCometsOrbitsColor(c.toVec3f());
 	//! @endcode
 	void setCometsOrbitsColor(const Vec3f& c);
 	//! Get the current color used to draw comet orbit lines.
@@ -424,8 +433,9 @@ public slots:
 	//! Set the color used to draw sednoid orbit lines.
 	//! @param c The color of the sednoid orbit lines (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setSednoidsOrbitsColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setSednoidsOrbitsColor(c.toVec3f());
 	//! @endcode
 	void setSednoidsOrbitsColor(const Vec3f& c);
 	//! Get the current color used to draw sednoid orbit lines.
@@ -435,8 +445,9 @@ public slots:
 	//! Set the color used to draw interstellar orbit (hyperbolic trajectory) lines.
 	//! @param c The color of the interstellar orbit lines (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setInterstellarOrbitsColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setInterstellarOrbitsColor(c.toVec3f());
 	//! @endcode
 	void setInterstellarOrbitsColor(const Vec3f& c);
 	//! Get the current color used to draw interstellar orbit lines.
@@ -446,8 +457,9 @@ public slots:
 	//! Set the color used to draw Mercury orbit line.
 	//! @param c The color of Mercury orbit line (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setMercuryOrbitColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setMercuryOrbitColor(c.toVec3f());
 	//! @endcode
 	void setMercuryOrbitColor(const Vec3f& c);
 	//! Get the current color used to draw Mercury orbit line.
@@ -457,8 +469,9 @@ public slots:
 	//! Set the color used to draw Venus orbit line.
 	//! @param c The color of Venus orbit line (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setVenusOrbitColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setVenusOrbitColor(c.toVec3f());
 	//! @endcode
 	void setVenusOrbitColor(const Vec3f& c);
 	//! Get the current color used to draw Venus orbit line.
@@ -468,8 +481,9 @@ public slots:
 	//! Set the color used to draw Earth orbit line.
 	//! @param c The color of Earth orbit line (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setEarthOrbitColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setEarthOrbitColor(c.toVec3f());
 	//! @endcode
 	void setEarthOrbitColor(const Vec3f& c);
 	//! Get the current color used to draw Earth orbit line.
@@ -479,8 +493,9 @@ public slots:
 	//! Set the color used to draw Mars orbit line.
 	//! @param c The color of Mars orbit line (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setMarsOrbitColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setMarsOrbitColor(c.toVec3f());
 	//! @endcode
 	void setMarsOrbitColor(const Vec3f& c);
 	//! Get the current color used to draw Mars orbit line.
@@ -490,8 +505,9 @@ public slots:
 	//! Set the color used to draw Jupiter orbit line.
 	//! @param c The color of Jupiter orbit line (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setJupiterOrbitColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setJupiterOrbitColor(c.toVec3f());
 	//! @endcode
 	void setJupiterOrbitColor(const Vec3f& c);
 	//! Get the current color used to draw Jupiter orbit line.
@@ -501,8 +517,9 @@ public slots:
 	//! Set the color used to draw Saturn orbit line.
 	//! @param c The color of Saturn orbit line (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setSaturnOrbitColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setSaturnOrbitColor(c.toVec3f());
 	//! @endcode
 	void setSaturnOrbitColor(const Vec3f& c);
 	//! Get the current color used to draw Saturn orbit line.
@@ -512,8 +529,9 @@ public slots:
 	//! Set the color used to draw Uranus orbit line.
 	//! @param c The color of Uranus orbit line (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setUranusOrbitColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setUranusOrbitColor(c.toVec3f());
 	//! @endcode
 	void setUranusOrbitColor(const Vec3f& c);
 	//! Get the current color used to draw Uranus orbit line.
@@ -523,8 +541,9 @@ public slots:
 	//! Set the color used to draw Neptune orbit line.
 	//! @param c The color of Neptune orbit line (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setNeptuneOrbitColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setNeptuneOrbitColor(c.toVec3f());
 	//! @endcode
 	void setNeptuneOrbitColor(const Vec3f& c);
 	//! Get the current color used to draw Neptune orbit line.
@@ -534,8 +553,9 @@ public slots:
 	//! Set the color used to draw planet trails lines.
 	//! @param c The color of the planet trails lines (R,G,B)
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setTrailsColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setTrailsColor(c.toVec3f());
 	//! @endcode
 	void setTrailsColor(const Vec3f& c) {if (c!=trailsColor) { trailsColor=c; emit trailsColorChanged(c);}}
 	//! Get the current color used to draw planet trails lines.
@@ -545,8 +565,9 @@ public slots:
 	//! Set the color used to draw planet pointers.
 	//! @param c The color of the planet pointers
 	//! @code
-	//! // example of usage in scripts
-	//! SolarSystem.setPointerColor(Vec3f(1.0,0.0,0.0));
+	//! // example of usage in scripts (Qt6-based Stellarium)
+	//! var c = new Color(1.0, 0.0, 0.0);
+	//! SolarSystem.setPointerColor(c.toVec3f());
 	//! @endcode
 	void setPointerColor(const Vec3f& c) {if (c!=pointerColor) {pointerColor=c; emit pointerColorChanged(c);}}
 	//! Get the current color used to draw planet pointers.
@@ -647,16 +668,12 @@ public slots:
 	//! @note: The structure of algorithms is almost identical, just the numbers are different!
 	//!        You should activate Mueller's algorithm to simulate the eye's impression. (Esp. Venus!)
 	void setApparentMagnitudeAlgorithmOnEarth(const QString &algorithm);
-
+	//! overload with numeric ID
+	void setApparentMagnitudeAlgorithmOnEarth(const Planet::ApparentMagnitudeAlgorithm id);
 	//! Get the algorithm used for computation of apparent magnitudes for planets in case observer on the Earth
 	//! @see setApparentMagnitudeAlgorithmOnEarth()
 	QString getApparentMagnitudeAlgorithmOnEarth() const;
 
-	//! Set flag which enable use native names for planets or not.
-	void setFlagNativePlanetNames(bool b);
-	//! Get the current value of the flag which enables showing native names for planets or not.
-	bool getFlagNativePlanetNames(void) const;
-
 	//! Set flag which enabled the showing of isolated trails for selected objects only or not
 	void setFlagIsolatedTrails(bool b);
 	//! Get the current value of the flag which enables showing of isolated trails for selected objects only or not.
@@ -688,7 +705,7 @@ public slots:
 	bool getFlagOrbitsWithMoons(void) const;
 
 	//! Set flag which enabled the showing of solar corona when atmosphere is disabled (true) of draw the corona when total solar eclipses is happened only (false)
-	void setFlagPermanentSolarCorona(bool b) {	if (flagPermanentSolarCorona!=b)	{ flagPermanentSolarCorona = b; emit flagPermanentSolarCoronaChanged(b); } }
+	void setFlagPermanentSolarCorona(bool b) {if (flagPermanentSolarCorona!=b){ flagPermanentSolarCorona = b; StelApp::immediateSave("viewing/flag_draw_sun_corona", b); emit flagPermanentSolarCoronaChanged(b); } }
 	//! Get the current value of the flag which enables showing of solar corona when atmosphere is disabled or when total solar eclipses is happened only.
 	bool getFlagPermanentSolarCorona(void) const { return flagPermanentSolarCorona; }
 
@@ -718,8 +735,10 @@ public slots:
 	bool getFlagEarthShadowEnlargementDanjon() const;
 
 	//! Set style of colors of orbits for Solar system bodies
+	//! @param style One of one_color | groups | major_planets | major_planets_minor_types
 	void setOrbitColorStyle(const QString &style);
 	//! Get style of colors of orbits for Solar system bodies
+	//! @return One of one_color | groups | major_planets | major_planets_minor_types
 	QString getOrbitColorStyle() const;
 
 	//! Get list of objects by type
@@ -766,6 +785,9 @@ public slots:
 	//! Configure the limiting absolute magnitude for plotting minor bodies. Configured value is clamped to -2..37 (practical limit)
 	void setMarkerMagThreshold(double m);
 
+	//! Enable the survey for use on the planet it describes
+	void enableSurvey(const HipsSurveyP& colors, const HipsSurveyP& normals, const HipsSurveyP& horizons);
+
 signals:
 	void labelsDisplayedChanged(bool b);
 	void flagOrbitsChanged(bool b);
@@ -779,7 +801,6 @@ signals:
 	void maxTrailPointsChanged(int max);
 	void maxTrailTimeExtentChanged(int max);
 	void flagPointerChanged(bool b);
-	void flagNativePlanetNamesChanged(bool b);
 	void flagPlanetsDisplayedChanged(bool b);
 	void flagPlanetsOrbitsChanged(bool b);
 	void flagPlanetsOrbitsOnlyChanged(bool b);
@@ -891,9 +912,8 @@ public:
 	//! Get the list of all the planet localized names
 	QStringList getAllPlanetLocalizedNames() const;
 
-	//! Get the list of all the minor planet common english names
-	QStringList getAllMinorPlanetCommonEnglishNames() const;
-
+	//! Get the list of all the minor planet english names
+	QStringList getAllMinorPlanetEnglishNames() const;
 
 	//! New 0.16: delete a planet from the solar system. Writes a warning to log if this is not a minor object.
 	bool removeMinorPlanet(const QString &name);
@@ -937,8 +957,9 @@ private slots:
 
 	//! Called when the sky culture is updated.
 	//! Loads native names of planets for a given sky culture.
-	//! @param skyCultureDir the name of the directory containing the sky culture to use.
-	void updateSkyCulture(const QString& skyCultureDir);
+	void updateSkyCulture(const StelSkyCulture& skyCulture);
+
+	void loadCultureSpecificNames(const QJsonObject& data);
 
 	//! Called following StelMainView::reloadShadersRequested
 	void reloadShaders();
@@ -1037,9 +1058,6 @@ private slots:
 	void setEphemerisSaturnMarkerColor(const Vec3f& c);
 	Vec3f getEphemerisSaturnMarkerColor(void) const;
 
-	//! Called when a new Hips survey has been loaded by the hips mgr.
-	void onNewSurvey(HipsSurveyP survey);
-
 	//! Taking the JD dates for each ephemeride and preparation the human readable dates according to the settings for dates
 	void fillEphemerisDates();
 
@@ -1114,7 +1132,7 @@ private:
 	bool flagSunScale;
 	double sunScale;
 
-	QFont planetNameFont;
+	int fontSize;
 
 	//! The amount of planet labels (between 0 and 10).
 	double labelsAmount;
@@ -1141,7 +1159,6 @@ private:
 
 	bool flagShow;
 	bool flagPointer;                           // show red cross selection pointer?
-	bool flagNativePlanetNames;                 // show native names for planets?
 	bool flagIsolatedTrails;
 	int numberIsolatedTrails;
 	int maxTrailPoints;                         // limit trails to a manageable size.
@@ -1180,7 +1197,8 @@ private:
 	Vec3f trailsColor;
 	Vec3f pointerColor;
 
-	QHash<QString, QString> planetNativeNamesMap, planetNativeNamesMeaningMap;
+	static const QMap<Planet::ApparentMagnitudeAlgorithm, QString> vMagAlgorithmMap;
+
 	QStringList minorBodies;
 
 	// 0.16pre observation GZ: this list contains pointers to all orbit objects,
@@ -1240,7 +1258,9 @@ private:
 	LinearFader markerFader;         // Useful for markers displayed for minor bodies regardless of magnitude
 
 public:
+	//! Draw a tiny symbol at x/y
 	bool drawAsteroidMarker(StelCore* core, StelPainter* sPainter, const float x, const float y, Vec3f &color);
+	//! return brightness for markers (from a fader, 0..1)
 	float getMarkerValue() const {return markerFader.getInterstate();}
 
 private:
