@@ -217,7 +217,7 @@ void HelpDialog::downloadComplete(QNetworkReply *reply)
 
 	updateState = HelpDialog::CompleteUpdates;
 
-	QString latestVersion = map["name"].toString();
+	QString latestVersion = map["tag_name"].toString();
 	latestVersion.replace("v","", Qt::CaseInsensitive);
 	QStringList v = latestVersion.split(".");
 	v.append("0"); // the latest number (PATCH) is always 0 for releases
@@ -492,12 +492,14 @@ void HelpDialog::updateAboutText(void) const
 
 	typedef QPair<QString, int> donator;
 	QVector<donator> financialContributors = {
-		// Individuals
-		{ "Laurence Holt", 1000 }, { "Daniel", 1000 }, { "John Bellora", 670 }, { "Jeff Moe", 512 }, { "Marla Pinaire", 470 },
-		{ "Vernon Hermsen", 324 }, { "Walter Dörfler", 300 }, { "Satish Mallesh", 260 }, { "Raul Prisacariu", 260 },
-		{ "Philippe Renoux", 250 }, { "Fito Martin", 250 }, { "SuEllen Shepard", 250 },  { "Vlad Magdalin", 250  },
-		// Organizations
-		{ "BairesDev", 6500 }, { "Astronomie-Werkstatt \"Sterne ohne Grenzen\"", 730 }, { "SSSTwitter", 500 }, { "Triplebyte", 280 }
+	        // Individuals
+	        { "Daniel", 2400 }, { "Bryan", 1000 }, { "Laurence Holt", 1000 }, { "John Bellora", 670 }, { "Marla Pinaire", 620 }, { "Jeff Moe", 512 },
+	        { "Peter Reigber", 400 }, { "Incognito", 345 }, { "Vernon Hermsen", 324 }, { "Michel Payette", 320 },  { "Incognito", 300 },
+	        { "James Lattis", 300 }, { "Walter Dörfler", 300 },  { "Raul Prisacariu", 310 }, { "Salvatore Ficicchia", 306 }, { "Satish Mallesh", 260 },
+	        { "Philippe Renoux", 250 },  { "Fito Martin", 250 }, { "SuEllen Shepard", 250 },  { "Vlad Magdalin", 250  },
+	        // Organizations
+	        { "BairesDev", 14000 }, { "Dotcom-Monitor", 1000 }, { "Astronomie-Werkstatt \"Sterne ohne Grenzen\"", 880 },
+	        { "SSSTwitter", 500 }, { "Triplebyte", 280 }
 	};
 	std::sort(financialContributors.begin(), financialContributors.end(), [](donator i, donator j){ return i.second > j.second; });
 	QStringList bestFinancialContributors;
@@ -511,9 +513,10 @@ void HelpDialog::updateAboutText(void) const
 
 	// populate About tab
 	QString newHtml = "<h1>" + StelUtils::getApplicationName() + "</h1>";
-	newHtml += QString("<p><strong>%1 %2").arg(q_("Version"), StelUtils::getApplicationVersion());
-	newHtml += QString("<br />%1 %2</strong></p>").arg(q_("Based on Qt"), QT_VERSION_STR);
-	if (!message.isEmpty())
+        newHtml += QString("<p><strong>%1 %2 (%3)</strong>").arg(q_("Version"), StelUtils::getApplicationVersion(), qc_(StelUtils::getAddressingMode(), "addressing mode"));
+        newHtml += QString("<br />%1 %2").arg(q_("Based on Qt"), QT_VERSION_STR);
+        newHtml += QString("<br />%1 %2</p>").arg(q_("Running on Operating System"), StelUtils::getOperatingSystemInfo());
+        if (!message.isEmpty())
 		newHtml += "<p><strong>" + message + "</strong></p>";
 	// Note: this legal notice is not suitable for translation
 	newHtml += QString("<h3>%1</h3>").arg(STELLARIUM_COPYRIGHT);
@@ -541,8 +544,8 @@ void HelpDialog::updateAboutText(void) const
 	newHtml += "<li>" + q_("Developer: %1").arg(QString("Alexander V. Wolf")).toHtmlEscaped() + "</li>";
 	newHtml += "<li>" + q_("Developer: %1").arg(QString("Ruslan Kabatsayev")).toHtmlEscaped() + "</li>";
 	newHtml += "<li>" + q_("Developer: %1").arg(QString("Worachate Boonplod")).toHtmlEscaped() + "</li>";
+	newHtml += "<li>" + q_("Developer: %1").arg(QString("Henry Leung")).toHtmlEscaped() + "</li>";
 	newHtml += "<li>" + q_("Sky cultures researcher: %1").arg(QString("Susanne M. Hoffmann")).toHtmlEscaped() + "</li>";
-	newHtml += "<li>" + q_("Continuous Integration: %1").arg(QString("Hans Lambermont")).toHtmlEscaped() + "</li>";
 	newHtml += "<li>" + q_("Tester: %1").arg(QString("Khalid AlAjaji")).toHtmlEscaped() + "</li></ul>";
 	newHtml += "<h3>" + q_("Former Developers").toHtmlEscaped() + "</h3>";
 	newHtml += "<p>"  + q_("Several people have made significant contributions, but are no longer active. Their work has made a big difference to the project:").toHtmlEscaped() + "</p><ul>";
@@ -557,9 +560,10 @@ void HelpDialog::updateAboutText(void) const
 	newHtml += "<li>" + q_("Developer: %1").arg(QString("Mike Storm")).toHtmlEscaped() + "</li>";
 	newHtml += "<li>" + q_("Developer: %1").arg(QString("Ferdinand Majerech")).toHtmlEscaped() + "</li>";
 	newHtml += "<li>" + q_("Developer: %1").arg(QString("Jörg Müller")).toHtmlEscaped() + "</li>";
-	newHtml += "<li>" + q_("Developer: %1").arg(QString("Marcos Cardinot")).toHtmlEscaped() + "</li>";	
+	newHtml += "<li>" + q_("Developer: %1").arg(QString("Marcos Cardinot")).toHtmlEscaped() + "</li>";
 	newHtml += "<li>" + q_("OSX Developer: %1").arg(QString("Nigel Kerr")).toHtmlEscaped() + "</li>";
-	newHtml += "<li>" + q_("OSX Developer: %1").arg(QString("Diego Marcos")).toHtmlEscaped() + "</li></ul>";
+	newHtml += "<li>" + q_("OSX Developer: %1").arg(QString("Diego Marcos")).toHtmlEscaped() + "</li>";
+	newHtml += "<li>" + q_("Continuous Integration: %1").arg(QString("Hans Lambermont")).toHtmlEscaped() + "</li></ul>";
 	newHtml += "<h3>" + q_("Contributors").toHtmlEscaped() + "</h3>";
 	newHtml += "<p>"  + q_("Many individuals have made contributions to the project and their work has made Stellarium better. Alphabetically sorted list of all contributors: %1.").arg(allContributors.join(", ")).toHtmlEscaped() + "</p>";
 	newHtml += "<h3>" + q_("Financial support").toHtmlEscaped() + "</h3>";
