@@ -45,8 +45,7 @@ public:
 	ShortcutsFilterModel(QObject* parent = Q_NULLPTR);
 	
 protected:
-	virtual bool filterAcceptsRow(int source_row,
-			      const QModelIndex &source_parent) const Q_DECL_OVERRIDE;
+	bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 };
 
 
@@ -56,7 +55,7 @@ class ShortcutsDialog : public StelDialog
 
 public:
 	ShortcutsDialog(QObject* parent);
-	~ShortcutsDialog() Q_DECL_OVERRIDE;
+	~ShortcutsDialog() override;
 
 	//! highlight items that have collisions with current lineEdits' state according to CSS.
 	//! Note: previous collisions aren't redrawn.
@@ -65,7 +64,7 @@ public:
 public slots:
 	//! restore colors of all items it TreeWidget to defaults.
 	void resetCollisions();
-	virtual void retranslate() Q_DECL_OVERRIDE;
+	void retranslate() override;
 	//! initialize editors state when current item changed.
 	void initEditors();
 	//! checks whether one QKeySequence is prefix of another.
@@ -88,7 +87,7 @@ public slots:
 
 protected:
 	//! Initialize the dialog widgets and connect the signals/slots.
-	virtual void createDialogContent() Q_DECL_OVERRIDE;
+	void createDialogContent() override;
 
 private:
 	//! checks whether given item can be changed by editors.
