@@ -61,6 +61,7 @@
 #include <QGraphicsWidget>
 #include <QGraphicsGridLayout>
 #include <QClipboard>
+#include <QMimeData>
 #include <QPalette>
 #include <QColor>
 #include <QAction>
@@ -69,7 +70,7 @@
 static QString applyScaleToCSS(const QString& css, const double scale)
 {
 	auto out = css;
-	const QRegularExpression pat("\\b([0-9.]+)px\\b");
+	static const QRegularExpression pat("\\b([0-9.]+)px\\b");
 	QRegularExpressionMatch match;
 	int pos = 0;
 	while((pos = out.indexOf(pat, pos, &match)) >= 0)
@@ -220,7 +221,7 @@ void StelGui::updateStelStyle()
 
 void StelGui::init(QGraphicsWidget *atopLevelGraphicsWidget)
 {
-	qDebug() << "Creating GUI ...";
+	qInfo() << "Creating GUI ...";
 
 	StelGuiBase::init(atopLevelGraphicsWidget);
 	skyGui = new SkyGui(atopLevelGraphicsWidget);
@@ -244,27 +245,22 @@ void StelGui::init(QGraphicsWidget *atopLevelGraphicsWidget)
 	// Connect all the GUI actions signals with the Core of Stellarium
 	StelActionMgr* actionsMgr = StelApp::getInstance().getStelActionManager();
 
-	// XXX: this should probably go into the script manager.
-	QString windowsGroup = N_("Windows");
-	QString miscGroup = N_("Miscellaneous");
-	QString infoGroup = N_("Selected object information");
-	actionsMgr->addAction("actionQuit_Global", miscGroup, N_("Quit"), this, "quit()", "Ctrl+Q", "Ctrl+X");
-
 #ifdef ENABLE_SCRIPTING
-	QString datetimeGroup = N_("Date and Time");
-	actionsMgr->addAction("actionIncrease_Script_Speed", datetimeGroup, N_("Speed up the script execution rate"), this, "increaseScriptSpeed()");
-	actionsMgr->addAction("actionDecrease_Script_Speed", datetimeGroup, N_("Slow down the script execution rate"), this, "decreaseScriptSpeed()");
-	actionsMgr->addAction("actionSet_Real_Script_Speed", datetimeGroup, N_("Set the normal script execution rate"), this, "setRealScriptSpeed()");
-	actionsMgr->addAction("actionStop_Script", datetimeGroup, N_("Stop script execution"), this, "stopScript()", "Ctrl+D, S");
-	#ifndef ENABLE_SCRIPT_QML
-	actionsMgr->addAction("actionPause_Script", datetimeGroup, N_("Pause script execution"), this, "pauseScript()", "Ctrl+D, P");
-	actionsMgr->addAction("actionResume_Script", datetimeGroup, N_("Resume script execution"), this, "resumeScript()", "Ctrl+D, R");
-	#endif
+        QString scriptsGroup = N_("Scripts");
+        actionsMgr->addAction("actionIncrease_Script_Speed", scriptsGroup, N_("Speed up the script execution rate"), this, "increaseScriptSpeed()");
+        actionsMgr->addAction("actionDecrease_Script_Speed", scriptsGroup, N_("Slow down the script execution rate"), this, "decreaseScriptSpeed()");
+        actionsMgr->addAction("actionSet_Real_Script_Speed", scriptsGroup, N_("Set the normal script execution rate"), this, "setRealScriptSpeed()");
+        actionsMgr->addAction("actionStop_Script", scriptsGroup, N_("Stop script execution"), this, "stopScript()", "Ctrl+D, S");
+#ifndef ENABLE_SCRIPT_QML
+        actionsMgr->addAction("actionPause_Script", scriptsGroup, N_("Pause script execution"), this, "pauseScript()", "Ctrl+D, P");
+        actionsMgr->addAction("actionResume_Script", scriptsGroup, N_("Resume script execution"), this, "resumeScript()", "Ctrl+D, R");
 #endif
+#endif
+
+        QString windowsGroup = N_("Windows");
 #ifdef ENABLE_SCRIPT_CONSOLE
 	actionsMgr->addAction("actionShow_ScriptConsole_Window_Global", windowsGroup, N_("Script console window"), scriptConsole, "visible", "F12", "", true);
 #endif
-
 	actionsMgr->addAction("actionShow_Help_Window_Global", windowsGroup, N_("Help window"), helpDialog, "visible", "F1", "", true);
 	actionsMgr->addAction("actionShow_Configuration_Window_Global", windowsGroup, N_("Configuration window"), configurationDialog, "visible", "F2", "", true);
 	actionsMgr->addAction("actionShow_Search_Window_Global", windowsGroup, N_("Search window"), searchDialog, "visible", "F3", "Ctrl+F", true);
@@ -274,7 +270,10 @@ void StelGui::init(QGraphicsWidget *atopLevelGraphicsWidget)
 	actionsMgr->addAction("actionShow_Shortcuts_Window_Global", windowsGroup, N_("Shortcuts window"), shortcutsDialog, "visible", "F7", "", true);
 	actionsMgr->addAction("actionShow_AstroCalc_Window_Global", windowsGroup, N_("Astronomical calculations window"), astroCalcDialog, "visible", "F10", "", true);
 	actionsMgr->addAction("actionShow_ObsList_Window_Global", windowsGroup, N_("Observing list"), obsListDialog, "visible", "Alt+B", "", true);
-	actionsMgr->addAction("actionSave_Copy_Object_Information_Global", miscGroup, N_("Copy selected object information to clipboard"), this, "copySelectedObjectInfo()", "Ctrl+Shift+C", "", true);
+
+        QString miscGroup = N_("Miscellaneous");
+        actionsMgr->addAction("actionQuit_Global", miscGroup, N_("Quit"), this, "quit()", "Ctrl+Q", "Ctrl+X");
+        actionsMgr->addAction("actionSave_Copy_Object_Information_Global", miscGroup, N_("Copy selected object information to clipboard"), this, "copySelectedObjectInfo()", "Ctrl+Shift+C", "", true);
 
 	QSettings* conf = StelApp::getInstance().getSettings();
 	Q_ASSERT(conf);
@@ -292,6 +291,7 @@ void StelGui::init(QGraphicsWidget *atopLevelGraphicsWidget)
 	connect(scriptMgr, SIGNAL(scriptStopped()), this, SLOT(scriptStopped()));
 #endif
 
+        QString infoGroup = N_("Selected object information");
 	actionsMgr->addAction("actionDisplayInfo_All",     infoGroup, N_("All available info"), this, "displayAllInfo()");
 	actionsMgr->addAction("actionDisplayInfo_Default", infoGroup, N_("Default info"), this, "displayDefaultInfo()");
 	actionsMgr->addAction("actionDisplayInfo_Short",   infoGroup, N_("Short info"), this, "displayShortInfo()");
@@ -491,7 +491,7 @@ void StelGui::setStelStyle(const QString& style)
 	QFile styleFile(qtStyleFileName);
 	if(styleFile.open(QIODevice::ReadOnly))
 	{
-		qDebug().noquote() << "Loading style file:" << styleFile.fileName();
+		qInfo().noquote() << "Loading style file:" << styleFile.fileName();
 		currentStelStyle.qtStyleSheet = styleFile.readAll();
 		styleFile.close();
 	}
@@ -1121,7 +1121,7 @@ void StelGui::setFlagShowHiPSButton(bool b)
 				QPixmap pxmapGlow32x32(":/graphicGui/miscGlow32x32.png");
 				QPixmap pxmapOn(":/graphicGui/btHIPS-on.png");
 				QPixmap pxmapOff(":/graphicGui/btHIPS-off.png");
-				btShowHiPS = new StelButton(nullptr, pxmapOn, pxmapOff, pxmapGlow32x32, "actionShow_Hips_Surveys");
+				btShowHiPS = new StelButton(nullptr, pxmapOn, pxmapOff, pxmapGlow32x32, "actionShow_Hips_Surveys", false, "actionShow_Hips_Surveys_dialog");
 			}
 			getButtonBar()->addButton(btShowHiPS, "040-nebulaeGroup");
 		} else {
@@ -1384,6 +1384,7 @@ void StelGui::setAutoHideHorizontalButtonBar(bool b)
 	if (skyGui->autoHideBottomBar!=b)
 	{
 		skyGui->autoHideBottomBar=b;
+		StelApp::immediateSave("gui/auto_hide_horizontal_toolbar", b);
 		emit autoHideHorizontalButtonBarChanged(b);
 	}
 }
@@ -1398,6 +1399,7 @@ void StelGui::setAutoHideVerticalButtonBar(bool b)
 	if (skyGui->autoHideLeftBar!=b)
 	{
 		skyGui->autoHideLeftBar=b;
+		StelApp::immediateSave("gui/auto_hide_vertical_toolbar", b);
 		emit autoHideVerticalButtonBarChanged(b);
 	}
 }
@@ -1527,7 +1529,12 @@ StelAction* StelGui::getAction(const QString& actionName) const
 
 void StelGui::copySelectedObjectInfo(void)
 {
-	QGuiApplication::clipboard()->setText(skyGui->infoPanel->getSelectedText());
+	const auto cb = QGuiApplication::clipboard();
+	const auto md = new QMimeData;
+	const auto colorRE = QRegularExpression(" color=\"?#[0-9a-f]+\"?");
+	md->setHtml(skyGui->infoPanel->getSelectedHTML().replace(colorRE, ""));
+	md->setText(skyGui->infoPanel->getSelectedText());
+	cb->setMimeData(md);
 }
 
 bool StelGui::getAstroCalcVisible() const
