@@ -29,6 +29,9 @@ class Translations
 	{
 		// Generate Gettext strings for traduction
 		Q_ASSERT(0);
+		
+		// TRANSLATORS: short name of dataset for DSO textures
+		NC_("Nebulae", "dataset short name");
 
 		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
 		N_("Planets");
@@ -572,13 +575,13 @@ class Translations
 		// TRANSLATORS: Description of the landscape tour script.
 		N_("Look around each installed landscape.");
 		// TRANSLATORS: Description of the sky culture tour script.
-		N_("Look at each installed sky culture.");
+		N_("Look at each installed sky culture. Label style is forced to be 'Native,Translated,Modern' regardless of user setting, unless environment variable STEL_SCRIPT_OBEY_SKYCULTURE_STYLE evaluates true. (Style is restored at end.)");
 		N_("Script to demonstrate a partial lunar eclipse.");
 		N_("Script to demonstrate a total lunar eclipse.");
 		N_("A slow, infinite tour of the sky, looking at random objects.");
 		N_("Script to demonstrate a total solar eclipse which has happened in 2009 (location=Rangpur, Bangladesh).");
 		N_("Script which runs automatically at startup");
-		N_("This script displays the constellations of the Zodiac. That means the constellations which lie along the line which the Sun traces across the celestial sphere over the course of a year.");
+		N_("This script displays the constellations of the Zodiac. That means the constellations which lie along the line which the Sun traces across the celestial sphere over the course of a year. Label style is forced to be 'Native,Translated,Modern' regardless of user setting, unless environment variable STEL_SCRIPT_OBEY_SKYCULTURE_STYLE evaluates true. It ends with changes in skyculture (if not disabled by env. var.), labeling style, and shows constellation figures, boundaries and ecliptic.");
 		N_("Due to the quirks in Mercury's orbit and rotation at certain spots the sun will rise & set 3 different times in one Mercury day.");
 		N_("Just before Mars eclipses the sun, Phobos pops out from behind and eclipses it first. Takes place between Scorpio and Sagittarius on April 26, 2017.");
 		N_("Just before Mars eclipses the sun, Phobos pops out from behind and eclipses it first. Takes place between Taurus and Gemini on July 23, 2031.");
@@ -586,8 +589,8 @@ class Translations
 		N_("Phobos occultations of Earth are common, as are occultations of Jupiter. But occultations of both on the same day are very rare. Here's one that takes place 1/23/2048. In real speed.");
 		N_("Phobos races ahead of Mars and transits the sun, passes through it and then retrogrades back towards the sun and just partially transits it again (only seen in the southern hemisphere of Deimos), then Mars totally eclipses the sun while Phobos transits in darkness between Mars and Deimos. When Phobos emerges from Mars it is still eclipsed and dimmed in Mars' shadow, only to light up later.");
 		N_("Screensaver of various happenings in the Solar System. 321 events in all!");
-		N_("A tour of the modern constellations.");
-		N_("A tour of the constellations of the selected sky culture.");
+		N_("A tour of the modern constellations. Label style is forced to be 'Native,Translated,Modern' regardless of user setting, unless environment variable STEL_SCRIPT_OBEY_SKYCULTURE_STYLE evaluates true. (Style is restored at end.)");
+		N_("A tour of the constellations of the selected sky culture. Label style is forced to be 'Native,Translated,Modern' regardless of user setting, unless environment variable STEL_SCRIPT_OBEY_SKYCULTURE_STYLE evaluates true. (Style is restored at end.)");
 		N_("Look at the Sun from big planets of Solar System and Pluto.");
 		N_("Best views of Earth from other Solar System bodies in the 21st Century.");
 		N_("Transit of Venus as seen from Sydney Australia, 6th June 2012.");
@@ -617,6 +620,217 @@ class Translations
 		N_("This script will help you make practical works for celestial navigation - he sets a random location and hides it from the GUI.");
 		N_("Jupiter's Moons Orbital Simulation");
 
+		// =====================================================================
+		// Translatable SIMBAD object types (SIMBAD: Object types - https://simbad.cds.unistra.fr/guide/otypes.htx)
+
+		NC_("Star", "SIMBAD object type");
+		NC_("Massive Star", "SIMBAD object type");
+		NC_("beta Cep Variable", "SIMBAD object type");
+		NC_("Evolved Supergiant", "SIMBAD object type");
+		NC_("Red Supergiant", "SIMBAD object type");
+		NC_("Yellow Supergiant", "SIMBAD object type");
+		NC_("Blue Supergiant", "SIMBAD object type");
+		NC_("Wolf-Rayet", "SIMBAD object type");
+		NC_("LBV=Luminous Blue Variable", "SIMBAD object type");
+		NC_("Neutron Star", "SIMBAD object type");
+		NC_("Pulsar", "SIMBAD object type");
+		NC_("Young Stellar Object", "SIMBAD object type");
+		NC_("Orion Variable", "SIMBAD object type");
+		NC_("T Tauri Star", "SIMBAD object type");
+		NC_("Herbig Ae/Be Star", "SIMBAD object type");
+		NC_("Outflow", "SIMBAD object type");
+		NC_("Herbig-Haro Object", "SIMBAD object type");
+		NC_("Main Sequence Star", "SIMBAD object type");
+		NC_("Be Star", "SIMBAD object type");
+		NC_("Blue Straggler", "SIMBAD object type");
+		NC_("SX Phe Variable", "SIMBAD object type");
+		NC_("gamma Dor Variable", "SIMBAD object type");
+		NC_("delta Sct Variable", "SIMBAD object type");
+		NC_("Evolved Star", "SIMBAD object type");
+		NC_("Red Giant Branch star", "SIMBAD object type");
+		NC_("Hot Subdwarf", "SIMBAD object type");
+		NC_("Horizontal Branch Star", "SIMBAD object type");
+		NC_("RR Lyrae Variable", "SIMBAD object type");
+		NC_("Red Clump Star", "SIMBAD object type");
+		NC_("Type II Cepheid Variable", "SIMBAD object type");
+		NC_("Cepheid Variable", "SIMBAD object type");
+		NC_("Classical Cepheid Variable", "SIMBAD object type");
+		NC_("Carbon Star", "SIMBAD object type");
+		NC_("S Star", "SIMBAD object type");
+		NC_("Long-Period Variable", "SIMBAD object type");
+		NC_("Asymptotic Giant Branch Star", "SIMBAD object type");
+		NC_("Mira Variable", "SIMBAD object type");
+		NC_("O-rich AGB Star", "SIMBAD object type");
+		NC_("OH/IR Star", "SIMBAD object type");
+		NC_("Post-AGB Star", "SIMBAD object type");
+		NC_("RV Tauri Variable", "SIMBAD object type");
+		NC_("Planetary Nebula", "SIMBAD object type");
+		NC_("White Dwarf", "SIMBAD object type");
+		NC_("ELMWD=Extremely Low Mass White Dwarf", "SIMBAD object type");
+		NC_("Chemically Peculiar Star", "SIMBAD object type");
+		NC_("alpha2 CVn Variable", "SIMBAD object type");
+		NC_("R CrB Variable", "SIMBAD object type");
+		NC_("CH Star", "SIMBAD object type");
+		NC_("Barium Star", "SIMBAD object type");
+		NC_("Dwarf Carbon Star", "SIMBAD object type");
+		NC_("Carbon-Enhanced Metal Poor Star", "SIMBAD object type");
+		NC_("Double or Multiple Star", "SIMBAD object type");
+		NC_("Eclipsing Binary", "SIMBAD object type");
+		NC_("Ellipsoidal Variable", "SIMBAD object type");
+		NC_("Spectroscopic Binary", "SIMBAD object type");
+		NC_("RS CVn Variable", "SIMBAD object type");
+		NC_("BY Dra Variable", "SIMBAD object type");
+		NC_("Symbiotic Star", "SIMBAD object type");
+		NC_("X-ray Binary", "SIMBAD object type");
+		NC_("Low Mass X-ray Binary", "SIMBAD object type");
+		NC_("High Mass X-ray Binary", "SIMBAD object type");
+		NC_("Cataclysmic Binary", "SIMBAD object type");
+		NC_("Classical Nova", "SIMBAD object type");
+		NC_("SuperNova", "SIMBAD object type");
+		NC_("Low-mass Star", "SIMBAD object type");
+		NC_("Brown Dwarf", "SIMBAD object type");
+		NC_("Extra-solar Planet", "SIMBAD object type");
+		NC_("Variable Star", "SIMBAD object type");
+		NC_("Irregular Variable", "SIMBAD object type");
+		NC_("Irregular Variable with rapid variations", "SIMBAD object type");
+		NC_("Eruptive Variable", "SIMBAD object type");
+		NC_("Rotating Variable", "SIMBAD object type");
+		NC_("Pulsating Variable", "SIMBAD object type");
+		NC_("Star showing Eclipses by its Planet", "SIMBAD object type");
+		NC_("Emission-line Star", "SIMBAD object type");
+		NC_("High Proper Motion Star", "SIMBAD object type");
+		NC_("High Velocity Star", "SIMBAD object type");
+		NC_("Cluster of Stars", "SIMBAD object type");
+		NC_("Globular Cluster", "SIMBAD object type");
+		NC_("Open Cluster", "SIMBAD object type");
+		NC_("Association of Stars", "SIMBAD object type");
+		NC_("Stellar Stream", "SIMBAD object type");
+		NC_("Moving Group", "SIMBAD object type");
+		NC_("Interstellar Medium Object", "SIMBAD object type");
+		NC_("Star Forming Region", "SIMBAD object type");
+		NC_("HII Region", "SIMBAD object type");
+		NC_("Cloud", "SIMBAD object type");
+		NC_("Nebula", "SIMBAD object type");
+		NC_("Reflection Nebula", "SIMBAD object type");
+		NC_("Molecular Cloud", "SIMBAD object type");
+		NC_("Dark Cloud (nebula)", "SIMBAD object type");
+		NC_("Globule (low-mass dark cloud)", "SIMBAD object type");
+		NC_("Cometary Globule / Pillar", "SIMBAD object type");
+		NC_("High-velocity Cloud", "SIMBAD object type");
+		NC_("Dense Core", "SIMBAD object type");
+		NC_("Bubble", "SIMBAD object type");
+		NC_("SuperNova Remnant", "SIMBAD object type");
+		NC_("Interstellar Shell", "SIMBAD object type");
+		NC_("Interstellar Filament", "SIMBAD object type");
+		NC_("Galaxy", "SIMBAD object type");
+		NC_("Low Surface Brightness Galaxy", "SIMBAD object type");
+		NC_("Blue Compact Galaxy", "SIMBAD object type");
+		NC_("Starburst Galaxy", "SIMBAD object type");
+		NC_("HII Galaxy", "SIMBAD object type");
+		NC_("Emission-line galaxy", "SIMBAD object type");
+		NC_("Active Galaxy Nucleus", "SIMBAD object type");
+		NC_("Seyfert Galaxy", "SIMBAD object type");
+		NC_("Seyfert 1 Galaxy", "SIMBAD object type");
+		NC_("Seyfert 2 Galaxy", "SIMBAD object type");
+		NC_("Radio Galaxy", "SIMBAD object type");
+		NC_("LINER-type Active Galaxy Nucleus", "SIMBAD object type");
+		NC_("Quasar", "SIMBAD object type");
+		NC_("Blazar", "SIMBAD object type");
+		NC_("BL Lac", "SIMBAD object type");
+		NC_("ULIRG, Ultra Luminous Infrared Galaxy", "SIMBAD object type");
+		NC_("Galaxy in Pair of Galaxies", "SIMBAD object type");
+		NC_("Galaxy towards a Group of Galaxies", "SIMBAD object type");
+		NC_("Galaxy towards a Cluster of Galaxies", "SIMBAD object type");
+		NC_("Brightest Galaxy in a Cluster (BCG)", "SIMBAD object type");
+		NC_("Interacting Galaxies", "SIMBAD object type");
+		NC_("Pair of Galaxies", "SIMBAD object type");
+		NC_("Group of Galaxies", "SIMBAD object type");
+		NC_("Compact Group of Galaxies", "SIMBAD object type");
+		NC_("Cluster of Galaxies", "SIMBAD object type");
+		NC_("Proto Cluster of Galaxies", "SIMBAD object type");
+		NC_("Supercluster of Galaxies", "SIMBAD object type");
+		NC_("Underdense Region of the Universe", "SIMBAD object type");
+		NC_("Gravitational Source", "SIMBAD object type");
+		NC_("(Micro)Lensing Event", "SIMBAD object type");
+		NC_("Gravitational Lens System (lens+images)", "SIMBAD object type");
+		NC_("Gravitational Lens", "SIMBAD object type");
+		NC_("Gravitationally Lensed Image", "SIMBAD object type");
+		NC_("Gravitationally Lensed Image of a Galaxy", "SIMBAD object type");
+		NC_("Gravitationally Lensed Image of a Quasar", "SIMBAD object type");
+		NC_("Black Hole", "SIMBAD object type");
+		NC_("Gravitational Wave Event", "SIMBAD object type");
+		NC_("Transient Event", "SIMBAD object type");
+		NC_("Variable source", "SIMBAD object type");
+		NC_("Radio Source", "SIMBAD object type");
+		NC_("Metric Radio Source", "SIMBAD object type");
+		NC_("Centimetric Radio Source", "SIMBAD object type");
+		NC_("Millimetric Radio Source", "SIMBAD object type");
+		NC_("Sub-Millimetric Source", "SIMBAD object type");
+		NC_("HI (21cm) Source", "SIMBAD object type");
+		NC_("Radio Burst", "SIMBAD object type");
+		NC_("Maser", "SIMBAD object type");
+		NC_("Infra-Red Source", "SIMBAD object type");
+		NC_("Far-IR source (λ >= 30 µm)", "SIMBAD object type");
+		NC_("Mid-IR Source (3 to 30 µm)", "SIMBAD object type");
+		NC_("Near-IR Source (λ < 3 µm)", "SIMBAD object type");
+		NC_("Optical Source", "SIMBAD object type");
+		NC_("Emission Object", "SIMBAD object type");
+		NC_("Blue Object", "SIMBAD object type");
+		NC_("UV-emission Source", "SIMBAD object type");
+		NC_("X-ray Source", "SIMBAD object type");
+		NC_("Ultra-luminous X-ray Source", "SIMBAD object type");
+		NC_("Gamma-ray Source", "SIMBAD object type");
+		NC_("Gamma-ray Burst", "SIMBAD object type");
+		NC_("Composite Object, Blend", "SIMBAD object type");
+		NC_("Not an Object (Error, Artefact, ...)", "SIMBAD object type");
+		NC_("Part of Cloud", "SIMBAD object type");
+		NC_("Part of a Galaxy", "SIMBAD object type");
+		NC_("Object of Unknown Nature", "SIMBAD object type");
+		NC_("Region defined in the Sky", "SIMBAD object type");
+
+		// =====================================================================
+		// Translatable UI elements with comments for translators (extracomments)
+
+		// src/gui/astroCalcDialog.ui:
+		// TRANSLATORS: This is a filter checkbox meaning "include penumbral lunar eclipses", so the adjective should be in plural (if applicable)
+		N_("Penumbral");
+		// TRANSLATORS: This is a filter checkbox meaning "include hybrid solar eclipses", so the adjective should be in plural (if applicable)
+		N_("Hybrid");
+		// TRANSLATORS: This is a filter checkbox meaning "include annular solar eclipses", so the adjective should be in plural (if applicable)
+		N_("Annular");
+		// TRANSLATORS: This is a filter checkbox meaning "include partial solar/lunar eclipses", so the adjective should be in plural (if applicable)
+		N_("Partial");
+		// TRANSLATORS: This is a filter checkbox meaning "include total solar/lunar eclipses", so the adjective should be in plural (if applicable)
+		N_("Total");
+		// TRANSLATORS: full phrase is 'show line'
+		NC_("line", "show line");
+		// TRANSLATORS: hours
+		N_("h");
+
+		NC_("64-bit", "addressing mode");
+		NC_("32-bit", "addressing mode");
+		NC_("none", "sky culture classification");
+
+		// src/gui/helpDialogGui.ui:
+		// TRANSLATORS: Same text as in the Configuration window!
+		N_("Edit keyboard shortcuts...");
+
+		// src/gui/searchDialogGui.ui:
+		// TRANSLATORS: See http://en.wikipedia.org/wiki/Bayer_designation
+		N_("Greek letters for Bayer designations");
+
+		// plugins/Satellites/src/gui/satellitesImportDialog.ui:
+		// TRANSLATORS: The title of the window will be set during runtime
+		N_("More Satellites");
+
+		// plugins/SolarSystemEditor/src/gui/manualImportWindow.ui:
+		// TRANSLATORS: The title of the window will be set during runtime
+		N_("Define an object");
+
+		// plugins/SolarSystemEditor/src/gui/mpcImportWindow.ui:
+		// TRANSLATORS: The title of the window will be set during runtime
+		N_("Import data");
+
 		// =====================================================================
 		// List of GUI elements (Qt's dialogs)
 		N_("&Undo");
@@ -676,5 +890,147 @@ class Translations
 		N_("New Folder");
 		N_("Show &hidden files");
 		N_("Search");
+		// =========================================================================
+		// In preparation of narration. These should go away after merge of branch "narration".
+		NC_("Andromeda"          , "IAU constellation name");
+		NC_("Antlia"             , "IAU constellation name");
+		NC_("Apus"               , "IAU constellation name");
+		NC_("Aquila"             , "IAU constellation name");
+		NC_("Aquarius"           , "IAU constellation name");
+		NC_("Ara"                , "IAU constellation name");
+		NC_("Aries"              , "IAU constellation name");
+		NC_("Auriga"             , "IAU constellation name");
+		NC_("Bootes"             , "IAU constellation name");
+		NC_("Canis Major"        , "IAU constellation name");
+		NC_("Canis Minor"        , "IAU constellation name");
+		NC_("Caelum"             , "IAU constellation name");
+		NC_("Camelopardalis"     , "IAU constellation name");
+		NC_("Capricornus"        , "IAU constellation name");
+		NC_("Carina"             , "IAU constellation name");
+		NC_("Cassiopeia"         , "IAU constellation name");
+		NC_("Centaurus"          , "IAU constellation name");
+		NC_("Cepheus"            , "IAU constellation name");
+		NC_("Cetus"              , "IAU constellation name");
+		NC_("Chamaeleon"         , "IAU constellation name");
+		NC_("Circinus"           , "IAU constellation name");
+		NC_("Cancer"             , "IAU constellation name");
+		NC_("Columba"            , "IAU constellation name");
+		NC_("Coma Berenices"     , "IAU constellation name");
+		NC_("Corona Australis"   , "IAU constellation name");
+		NC_("Corona Borealis"    , "IAU constellation name");
+		NC_("Crater"             , "IAU constellation name");
+		NC_("Crux"               , "IAU constellation name");
+		NC_("Corvus"             , "IAU constellation name");
+		NC_("Canes Venatici"     , "IAU constellation name");
+		NC_("Cygnus"             , "IAU constellation name");
+		NC_("Delphinus"          , "IAU constellation name");
+		NC_("Dorado"             , "IAU constellation name");
+		NC_("Draco"              , "IAU constellation name");
+		NC_("Equuleus"           , "IAU constellation name");
+		NC_("Eridanus"           , "IAU constellation name");
+		NC_("Fornax"             , "IAU constellation name");
+		NC_("Gemini"             , "IAU constellation name");
+		NC_("Grus"               , "IAU constellation name");
+		NC_("Hercules"           , "IAU constellation name");
+		NC_("Horologium"         , "IAU constellation name");
+		NC_("Hydra"              , "IAU constellation name");
+		NC_("Hydrus"             , "IAU constellation name");
+		NC_("Indus"              , "IAU constellation name");
+		NC_("Leo Minor"          , "IAU constellation name");
+		NC_("Lacerta"            , "IAU constellation name");
+		NC_("Leo"                , "IAU constellation name");
+		NC_("Lepus"              , "IAU constellation name");
+		NC_("Libra"              , "IAU constellation name");
+		NC_("Lupus"              , "IAU constellation name");
+		NC_("Lynx"               , "IAU constellation name");
+		NC_("Lyra"               , "IAU constellation name");
+		NC_("Mensa"              , "IAU constellation name");
+		NC_("Microscopium"       , "IAU constellation name");
+		NC_("Monoceros"          , "IAU constellation name");
+		NC_("Musca"              , "IAU constellation name");
+		NC_("Norma"              , "IAU constellation name");
+		NC_("Octans"             , "IAU constellation name");
+		NC_("Ophiuchus"          , "IAU constellation name");
+		NC_("Orion"              , "IAU constellation name");
+		NC_("Pavo"               , "IAU constellation name");
+		NC_("Pegasus"            , "IAU constellation name");
+		NC_("Perseus"            , "IAU constellation name");
+		NC_("Phoenix"            , "IAU constellation name");
+		NC_("Pictor"             , "IAU constellation name");
+		NC_("Piscis Austrinus"   , "IAU constellation name");
+		NC_("Pisces"             , "IAU constellation name");
+		NC_("Puppis"             , "IAU constellation name");
+		NC_("Pyxis"              , "IAU constellation name");
+		NC_("Reticulum"          , "IAU constellation name");
+		NC_("Sculptor"           , "IAU constellation name");
+		NC_("Scorpius"           , "IAU constellation name");
+		NC_("Scutum"             , "IAU constellation name");
+		NC_("Serpens"            , "IAU constellation name");
+		NC_("Sextans"            , "IAU constellation name");
+		NC_("Sagitta"            , "IAU constellation name");
+		NC_("Sagittarius"        , "IAU constellation name");
+		NC_("Taurus"             , "IAU constellation name");
+		NC_("Telescopium"        , "IAU constellation name");
+		NC_("Triangulum Australe", "IAU constellation name");
+		NC_("Triangulum"         , "IAU constellation name");
+		NC_("Tucana"             , "IAU constellation name");
+		NC_("Ursa Major"         , "IAU constellation name");
+		NC_("Ursa Minor"         , "IAU constellation name");
+		NC_("Vela"               , "IAU constellation name");
+		NC_("Virgo"              , "IAU constellation name");
+		NC_("Volans"             , "IAU constellation name");
+		NC_("Vulpecula"          , "IAU constellation name");
+		NC_("a Galaxy"                     , "Nebula narration");
+		NC_("an Active galaxy"             , "Nebula narration");
+		NC_("a Radio galaxy"               , "Nebula narration");
+		NC_("an Interacting galaxy"        , "Nebula narration");
+		NC_("a Quasar"                     , "Nebula narration");
+		NC_("a Star cluster"               , "Nebula narration");
+		NC_("an Open star cluster"         , "Nebula narration");
+		NC_("a Globular star cluster"      , "Nebula narration");
+		NC_("a Stellar association"        , "Nebula narration");
+		NC_("a Star cloud"                 , "Nebula narration");
+		NC_("A nebula"                     , "Nebula narration");
+		NC_("a Planetary nebula"           , "Nebula narration");
+		NC_("a Dark Nebula"                , "Nebula narration");
+		NC_("a Reflection nebula"          , "Nebula narration");
+		NC_("a Bipolar nebula"             , "Nebula narration");
+		NC_("an emission nebula"           , "Nebula narration");
+		NC_("a cluster associated with nebulosity", "Nebula narration");
+		NC_("an H two region"              , "Nebula narration");
+		NC_("a Supernova remnant"          , "Nebula narration");
+		NC_("Interstellar matter"          , "Nebula narration");
+		NC_("an Emission object"           , "Nebula narration");
+		NC_("a BL Lacertae object"         , "Nebula narration");
+		NC_("a Blazar"                     , "Nebula narration");
+		NC_("a Molecular Cloud"            , "Nebula narration");
+		NC_("a Young Stellar Object"       , "Nebula narration");
+		NC_("a Possible Quasar"            , "Nebula narration");
+		NC_("a Possible Planetary Nebula"  , "Nebula narration");
+		NC_("a Protoplanetary Nebula"      , "Nebula narration");
+		NC_("a Star"                       , "Nebula narration");
+		NC_("a Symbiotic Star"             , "Nebula narration");
+		NC_("an Emission-line Star"        , "Nebula narration");
+		NC_("a Supernova Candidate"        , "Nebula narration");
+		NC_("a Supernova Remnant Candidate", "Nebula narration");
+		NC_("a cluster of Galaxies"        , "Nebula narration");
+		NC_("a part of a Galaxy"           , "Nebula narration");
+		NC_("a region of the sky"          , "Nebula narration");
+		NC_("an object of unknown type"    , "Nebula narration");
+		NC_("a star"                       , "object narration");
+		NC_("a major planet"               , "object narration");
+		NC_("a planet moon"                , "object narration");
+		NC_("an observer"                  , "object narration");
+		NC_("an artificial object"         , "object narration");
+		NC_("an asteroid"                  , "object narration");
+		NC_("a plutino"                    , "object narration");
+		NC_("a comet"                      , "object narration");
+		NC_("a dwarf planet"               , "object narration");
+		NC_("a cubewano"                   , "object narration");
+		NC_("a scattered disc object"      , "object narration");
+		NC_("an Oort Cloud Object"         , "object narration");
+		NC_("a sednoid"                    , "object narration");
+		NC_("an interstellar object"       , "object narration");
+		NC_("an object of undefined type"  , "object narration");
 	}
 };
